pub struct LiveEventPreferences<'a> {
pub hidden_feed_ids: Option<Vec<CowStr<'a>>>,
pub hide_all_feeds: Option<bool>,
pub extra_data: Option<BTreeMap<SmolStr, Data<'a>>>,
}Expand description
Preferences for live events.
Fields
A list of feed IDs that the user has hidden from live events.
hide_all_feeds: Option<bool>Whether to hide all feeds from live events. Defaults to false.
extra_data: Option<BTreeMap<SmolStr, Data<'a>>>Trait Implementations
Sourceimpl<'a> Clone for LiveEventPreferences<'a>
impl<'a> Clone for LiveEventPreferences<'a>
Sourcefn clone(&self) -> LiveEventPreferences<'a>
fn clone(&self) -> LiveEventPreferences<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for LiveEventPreferences<'a>
impl<'a> Debug for LiveEventPreferences<'a>
Sourceimpl Default for LiveEventPreferences<'_>
impl Default for LiveEventPreferences<'_>
Sourceimpl<'de: 'a, 'a> Deserialize<'de> for LiveEventPreferences<'a>
impl<'de: 'a, 'a> Deserialize<'de> for LiveEventPreferences<'a>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> IntoStatic for LiveEventPreferences<'a>
impl<'a> IntoStatic for LiveEventPreferences<'a>
Sourcetype Output = LiveEventPreferences<'static>
type Output = LiveEventPreferences<'static>
The “owned” variant of the type. For
Cow<'a, str>, this is Cow<'static, str>, for example.Sourcefn into_static(self) -> Self::Output
fn into_static(self) -> Self::Output
Turns the value into an “owned” variant, which can then be returned, moved, etc. Read more
Sourceimpl<'a> LexiconSchema for LiveEventPreferences<'a>
impl<'a> LexiconSchema for LiveEventPreferences<'a>
Sourcefn lexicon_doc() -> LexiconDoc<'static>
fn lexicon_doc() -> LexiconDoc<'static>
Generate the lexicon document for this type Read more
Sourcefn validate(&self) -> Result<(), ConstraintError>
fn validate(&self) -> Result<(), ConstraintError>
Validate an instance against lexicon constraints Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether this type should be inlined vs referenced Read more
Sourceimpl<'a> PartialEq for LiveEventPreferences<'a>
impl<'a> PartialEq for LiveEventPreferences<'a>
Sourceimpl<'a> Serialize for LiveEventPreferences<'a>
impl<'a> Serialize for LiveEventPreferences<'a>
impl<'a> Eq for LiveEventPreferences<'a>
impl<'a> StructuralPartialEq for LiveEventPreferences<'a>