pub struct ProfileViewBuilder<'a, S: State> { /* private fields */ }Expand description
Builder for constructing an instance of this type
Implementations
Sourceimpl<'a> ProfileViewBuilder<'a, Empty>
impl<'a> ProfileViewBuilder<'a, Empty>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn associated(self, value: impl Into<Option<ProfileAssociated<'a>>>) -> Self
pub fn associated(self, value: impl Into<Option<ProfileAssociated<'a>>>) -> Self
Set the associated field (optional)
Sourcepub fn maybe_associated(self, value: Option<ProfileAssociated<'a>>) -> Self
pub fn maybe_associated(self, value: Option<ProfileAssociated<'a>>) -> Self
Set the associated field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn created_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn created_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the createdAt field (optional)
Sourcepub fn maybe_created_at(self, value: Option<Datetime>) -> Self
pub fn maybe_created_at(self, value: Option<Datetime>) -> Self
Set the createdAt field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn description(self, value: impl Into<Option<CowStr<'a>>>) -> Self
pub fn description(self, value: impl Into<Option<CowStr<'a>>>) -> Self
Set the description field (optional)
Sourcepub fn maybe_description(self, value: Option<CowStr<'a>>) -> Self
pub fn maybe_description(self, value: Option<CowStr<'a>>) -> Self
Set the description field to an Option value (optional)
Sourceimpl<'a, S> ProfileViewBuilder<'a, S>
impl<'a, S> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn display_name(self, value: impl Into<Option<CowStr<'a>>>) -> Self
pub fn display_name(self, value: impl Into<Option<CowStr<'a>>>) -> Self
Set the displayName field (optional)
Sourcepub fn maybe_display_name(self, value: Option<CowStr<'a>>) -> Self
pub fn maybe_display_name(self, value: Option<CowStr<'a>>) -> Self
Set the displayName field to an Option value (optional)
Sourceimpl<'a, S> ProfileViewBuilder<'a, S>
impl<'a, S> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn indexed_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn indexed_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the indexedAt field (optional)
Sourcepub fn maybe_indexed_at(self, value: Option<Datetime>) -> Self
pub fn maybe_indexed_at(self, value: Option<Datetime>) -> Self
Set the indexedAt field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn status(self, value: impl Into<Option<StatusView<'a>>>) -> Self
pub fn status(self, value: impl Into<Option<StatusView<'a>>>) -> Self
Set the status field (optional)
Sourcepub fn maybe_status(self, value: Option<StatusView<'a>>) -> Self
pub fn maybe_status(self, value: Option<StatusView<'a>>) -> Self
Set the status field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn verification(
self,
value: impl Into<Option<VerificationState<'a>>>,
) -> Self
pub fn verification( self, value: impl Into<Option<VerificationState<'a>>>, ) -> Self
Set the verification field (optional)
Sourcepub fn maybe_verification(self, value: Option<VerificationState<'a>>) -> Self
pub fn maybe_verification(self, value: Option<VerificationState<'a>>) -> Self
Set the verification field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn viewer(self, value: impl Into<Option<ViewerState<'a>>>) -> Self
pub fn viewer(self, value: impl Into<Option<ViewerState<'a>>>) -> Self
Set the viewer field (optional)
Sourcepub fn maybe_viewer(self, value: Option<ViewerState<'a>>) -> Self
pub fn maybe_viewer(self, value: Option<ViewerState<'a>>) -> Self
Set the viewer field to an Option value (optional)
Sourceimpl<'a, S> ProfileViewBuilder<'a, S>
impl<'a, S> ProfileViewBuilder<'a, S>
Sourcepub fn build(self) -> ProfileView<'a>
pub fn build(self) -> ProfileView<'a>
Build the final struct
Sourcepub fn build_with_data(
self,
extra_data: BTreeMap<SmolStr, Data<'a>>,
) -> ProfileView<'a>
pub fn build_with_data( self, extra_data: BTreeMap<SmolStr, Data<'a>>, ) -> ProfileView<'a>
Build the final struct with custom extra_data