pub struct ProfileViewDetailedBuilder<'a, S: State> { /* private fields */ }Expand description
Builder for constructing an instance of this type
Implementations
Sourceimpl<'a> ProfileViewDetailedBuilder<'a, Empty>
impl<'a> ProfileViewDetailedBuilder<'a, Empty>
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn associated(self, value: impl Into<Option<ProfileAssociated<'a>>>) -> Self
pub fn associated(self, value: impl Into<Option<ProfileAssociated<'a>>>) -> Self
Set the associated field (optional)
Sourcepub fn maybe_associated(self, value: Option<ProfileAssociated<'a>>) -> Self
pub fn maybe_associated(self, value: Option<ProfileAssociated<'a>>) -> Self
Set the associated field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Set the banner field (optional)
Set the banner field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn created_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn created_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the createdAt field (optional)
Sourcepub fn maybe_created_at(self, value: Option<Datetime>) -> Self
pub fn maybe_created_at(self, value: Option<Datetime>) -> Self
Set the createdAt field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn description(self, value: impl Into<Option<CowStr<'a>>>) -> Self
pub fn description(self, value: impl Into<Option<CowStr<'a>>>) -> Self
Set the description field (optional)
Sourcepub fn maybe_description(self, value: Option<CowStr<'a>>) -> Self
pub fn maybe_description(self, value: Option<CowStr<'a>>) -> Self
Set the description field to an Option value (optional)
Sourceimpl<'a, S> ProfileViewDetailedBuilder<'a, S>
impl<'a, S> ProfileViewDetailedBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn display_name(self, value: impl Into<Option<CowStr<'a>>>) -> Self
pub fn display_name(self, value: impl Into<Option<CowStr<'a>>>) -> Self
Set the displayName field (optional)
Sourcepub fn maybe_display_name(self, value: Option<CowStr<'a>>) -> Self
pub fn maybe_display_name(self, value: Option<CowStr<'a>>) -> Self
Set the displayName field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn followers_count(self, value: impl Into<Option<i64>>) -> Self
pub fn followers_count(self, value: impl Into<Option<i64>>) -> Self
Set the followersCount field (optional)
Sourcepub fn maybe_followers_count(self, value: Option<i64>) -> Self
pub fn maybe_followers_count(self, value: Option<i64>) -> Self
Set the followersCount field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn follows_count(self, value: impl Into<Option<i64>>) -> Self
pub fn follows_count(self, value: impl Into<Option<i64>>) -> Self
Set the followsCount field (optional)
Sourcepub fn maybe_follows_count(self, value: Option<i64>) -> Self
pub fn maybe_follows_count(self, value: Option<i64>) -> Self
Set the followsCount field to an Option value (optional)
Sourceimpl<'a, S> ProfileViewDetailedBuilder<'a, S>
impl<'a, S> ProfileViewDetailedBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn indexed_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn indexed_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the indexedAt field (optional)
Sourcepub fn maybe_indexed_at(self, value: Option<Datetime>) -> Self
pub fn maybe_indexed_at(self, value: Option<Datetime>) -> Self
Set the indexedAt field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn joined_via_starter_pack(
self,
value: impl Into<Option<StarterPackViewBasic<'a>>>,
) -> Self
pub fn joined_via_starter_pack( self, value: impl Into<Option<StarterPackViewBasic<'a>>>, ) -> Self
Set the joinedViaStarterPack field (optional)
Sourcepub fn maybe_joined_via_starter_pack(
self,
value: Option<StarterPackViewBasic<'a>>,
) -> Self
pub fn maybe_joined_via_starter_pack( self, value: Option<StarterPackViewBasic<'a>>, ) -> Self
Set the joinedViaStarterPack field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn pinned_post(self, value: impl Into<Option<StrongRef<'a>>>) -> Self
pub fn pinned_post(self, value: impl Into<Option<StrongRef<'a>>>) -> Self
Set the pinnedPost field (optional)
Sourcepub fn maybe_pinned_post(self, value: Option<StrongRef<'a>>) -> Self
pub fn maybe_pinned_post(self, value: Option<StrongRef<'a>>) -> Self
Set the pinnedPost field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn posts_count(self, value: impl Into<Option<i64>>) -> Self
pub fn posts_count(self, value: impl Into<Option<i64>>) -> Self
Set the postsCount field (optional)
Sourcepub fn maybe_posts_count(self, value: Option<i64>) -> Self
pub fn maybe_posts_count(self, value: Option<i64>) -> Self
Set the postsCount field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn status(self, value: impl Into<Option<StatusView<'a>>>) -> Self
pub fn status(self, value: impl Into<Option<StatusView<'a>>>) -> Self
Set the status field (optional)
Sourcepub fn maybe_status(self, value: Option<StatusView<'a>>) -> Self
pub fn maybe_status(self, value: Option<StatusView<'a>>) -> Self
Set the status field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn verification(
self,
value: impl Into<Option<VerificationState<'a>>>,
) -> Self
pub fn verification( self, value: impl Into<Option<VerificationState<'a>>>, ) -> Self
Set the verification field (optional)
Sourcepub fn maybe_verification(self, value: Option<VerificationState<'a>>) -> Self
pub fn maybe_verification(self, value: Option<VerificationState<'a>>) -> Self
Set the verification field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn viewer(self, value: impl Into<Option<ViewerState<'a>>>) -> Self
pub fn viewer(self, value: impl Into<Option<ViewerState<'a>>>) -> Self
Set the viewer field (optional)
Sourcepub fn maybe_viewer(self, value: Option<ViewerState<'a>>) -> Self
pub fn maybe_viewer(self, value: Option<ViewerState<'a>>) -> Self
Set the viewer field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
impl<'a, S: State> ProfileViewDetailedBuilder<'a, S>
Sourceimpl<'a, S> ProfileViewDetailedBuilder<'a, S>
impl<'a, S> ProfileViewDetailedBuilder<'a, S>
Sourcepub fn build(self) -> ProfileViewDetailed<'a>
pub fn build(self) -> ProfileViewDetailed<'a>
Build the final struct
Sourcepub fn build_with_data(
self,
extra_data: BTreeMap<SmolStr, Data<'a>>,
) -> ProfileViewDetailed<'a>
pub fn build_with_data( self, extra_data: BTreeMap<SmolStr, Data<'a>>, ) -> ProfileViewDetailed<'a>
Build the final struct with custom extra_data