pub struct Draft<S: BosStr = DefaultStr> {
pub device_id: Option<S>,
pub device_name: Option<S>,
pub langs: Option<Vec<Language>>,
pub postgate_embedding_rules: Option<Vec<DisableRule<S>>>,
pub posts: Vec<DraftPost<S>>,
pub threadgate_allow: Option<Vec<DraftThreadgateAllowItem<S>>>,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Expand description
A draft containing an array of draft posts.
Fields
device_id: Option<S>UUIDv4 identifier of the device that created this draft.
device_name: Option<S>The device and/or platform on which the draft was created.
langs: Option<Vec<Language>>Indicates human language of posts primary text content.
postgate_embedding_rules: Option<Vec<DisableRule<S>>>Embedding rules for the postgates to be created when this draft is published.
posts: Vec<DraftPost<S>>Array of draft posts that compose this draft.
threadgate_allow: Option<Vec<DraftThreadgateAllowItem<S>>>Allow-rules for the threadgate to be created when this draft is published.
extra_data: Option<BTreeMap<SmolStr, Data<S>>>Implementations
Sourceimpl Draft<DefaultStr>
impl Draft<DefaultStr>
Sourcepub fn new() -> DraftBuilder<Empty, DefaultStr>
pub fn new() -> DraftBuilder<Empty, DefaultStr>
Create a new builder for this type, using the default string type (DefaultStr = SmolStr) if needed