pub struct DraftPost<'a> {
pub embed_externals: Option<Vec<DraftEmbedExternal<'a>>>,
pub embed_images: Option<Vec<DraftEmbedImage<'a>>>,
pub embed_records: Option<Vec<DraftEmbedRecord<'a>>>,
pub embed_videos: Option<Vec<DraftEmbedVideo<'a>>>,
pub labels: Option<SelfLabels<'a>>,
pub text: CowStr<'a>,
pub extra_data: Option<BTreeMap<SmolStr, Data<'a>>>,
}Expand description
One of the posts that compose a draft.
Fields
embed_externals: Option<Vec<DraftEmbedExternal<'a>>>embed_images: Option<Vec<DraftEmbedImage<'a>>>embed_records: Option<Vec<DraftEmbedRecord<'a>>>embed_videos: Option<Vec<DraftEmbedVideo<'a>>>labels: Option<SelfLabels<'a>>Self-label values for this post. Effectively content warnings.
text: CowStr<'a>The primary post content. It has a higher limit than post contents to allow storing a larger text that can later be refined into smaller posts.
extra_data: Option<BTreeMap<SmolStr, Data<'a>>>Trait Implementations
Sourceimpl<'de: 'a, 'a> Deserialize<'de> for DraftPost<'a>
impl<'de: 'a, 'a> Deserialize<'de> for DraftPost<'a>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> IntoStatic for DraftPost<'a>
impl<'a> IntoStatic for DraftPost<'a>
Sourceimpl<'a> LexiconSchema for DraftPost<'a>
impl<'a> LexiconSchema for DraftPost<'a>
Sourcefn lexicon_doc() -> LexiconDoc<'static>
fn lexicon_doc() -> LexiconDoc<'static>
Generate the lexicon document for this type Read more
Sourcefn validate(&self) -> Result<(), ConstraintError>
fn validate(&self) -> Result<(), ConstraintError>
Validate an instance against lexicon constraints Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether this type should be inlined vs referenced Read more
impl<'a> Eq for DraftPost<'a>
impl<'a> StructuralPartialEq for DraftPost<'a>