pub struct ViewExternal<S: BosStr = DefaultStr> {
pub associated_profiles: Option<Vec<ProfileViewBasic<S>>>,
pub associated_refs: Option<Vec<StrongRef<S>>>,
pub created_at: Option<Datetime>,
pub description: S,
pub labels: Option<Vec<Label<S>>>,
pub reading_time: Option<i64>,
pub source: Option<ViewExternalSource<S>>,
pub thumb: Option<UriValue<S>>,
pub title: S,
pub updated_at: Option<Datetime>,
pub uri: UriValue<S>,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Fields
associated_profiles: Option<Vec<ProfileViewBasic<S>>>Profiles of the owners of the Atmosphere records that backed this view.
associated_refs: Option<Vec<StrongRef<S>>>StrongRefs (uri+cid) of the Atmosphere records that backed this view.
created_at: Option<Datetime>When the external content was created, if available. Example: a publication date, for an article.
description: Slabels: Option<Vec<Label<S>>>reading_time: Option<i64>Estimated reading time in minutes, if applicable and available.
source: Option<ViewExternalSource<S>>thumb: Option<UriValue<S>>title: Supdated_at: Option<Datetime>When the external content was updated, if available.
uri: UriValue<S>extra_data: Option<BTreeMap<SmolStr, Data<S>>>Implementations
Sourceimpl ViewExternal<DefaultStr>
impl ViewExternal<DefaultStr>
Sourcepub fn new() -> ViewExternalBuilder<Empty, DefaultStr>
pub fn new() -> ViewExternalBuilder<Empty, DefaultStr>
Create a new builder for this type, using the default string type (DefaultStr = SmolStr) if needed
Sourceimpl<S: BosStr> ViewExternal<S>
impl<S: BosStr> ViewExternal<S>
Sourcepub fn builder() -> ViewExternalBuilder<Empty, S>
pub fn builder() -> ViewExternalBuilder<Empty, S>
Create a new builder for this type