pub struct GetEmbedExternalViewOutput<S: BosStr = DefaultStr> {
pub associated_records: Option<Vec<Data<S>>>,
pub associated_refs: Option<Vec<StrongRef<S>>>,
pub view: Option<View<S>>,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Fields
associated_records: Option<Vec<Data<S>>>associated_refs: Option<Vec<StrongRef<S>>>StrongRefs (URI+CID) of the Atmosphere records that backed this view, suitable for embedding into a post’s external.associatedRefs.
view: Option<View<S>>Hydrated view of the embed. Present only when the resolved records back the requested URL and supply enough information to populate the required viewExternal fields. Omitted alongside the rest of the response when no records resolved or validation failed.
extra_data: Option<BTreeMap<SmolStr, Data<S>>>Trait Implementations
Sourceimpl<S: Clone + BosStr> Clone for GetEmbedExternalViewOutput<S>
impl<S: Clone + BosStr> Clone for GetEmbedExternalViewOutput<S>
Sourcefn clone(&self) -> GetEmbedExternalViewOutput<S>
fn clone(&self) -> GetEmbedExternalViewOutput<S>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<S: Default + BosStr> Default for GetEmbedExternalViewOutput<S>
impl<S: Default + BosStr> Default for GetEmbedExternalViewOutput<S>
Sourcefn default() -> GetEmbedExternalViewOutput<S>
fn default() -> GetEmbedExternalViewOutput<S>
Returns the “default value” for a type. Read more
Sourceimpl<'de, S> Deserialize<'de> for GetEmbedExternalViewOutput<S>where
S: Deserialize<'de> + BosStr,
impl<'de, S> Deserialize<'de> for GetEmbedExternalViewOutput<S>where
S: Deserialize<'de> + BosStr,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<S: Eq + BosStr> Eq for GetEmbedExternalViewOutput<S>
Sourceimpl<S: BosStr + IntoStatic> IntoStatic for GetEmbedExternalViewOutput<S>
impl<S: BosStr + IntoStatic> IntoStatic for GetEmbedExternalViewOutput<S>
Sourcetype Output = GetEmbedExternalViewOutput<<S as IntoStatic>::Output>
type Output = GetEmbedExternalViewOutput<<S as IntoStatic>::Output>
The “owned” variant of the type. For
Cow<'a, str>, this is Cow<'static, str>, for example.Sourcefn into_static(self) -> Self::Output
fn into_static(self) -> Self::Output
Turns the value into an “owned” variant, which can then be returned, moved, etc. Read more
Sourceimpl<S: PartialEq + BosStr> PartialEq for GetEmbedExternalViewOutput<S>
impl<S: PartialEq + BosStr> PartialEq for GetEmbedExternalViewOutput<S>
Sourcefn eq(&self, other: &GetEmbedExternalViewOutput<S>) -> bool
fn eq(&self, other: &GetEmbedExternalViewOutput<S>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<S> Serialize for GetEmbedExternalViewOutput<S>
impl<S> Serialize for GetEmbedExternalViewOutput<S>
impl<S: BosStr> StructuralPartialEq for GetEmbedExternalViewOutput<S>