pub struct Generator<'a> {
pub accepts_interactions: Option<bool>,
pub avatar: Option<BlobRef<'a>>,
pub content_mode: Option<GeneratorContentMode<'a>>,
pub created_at: Datetime,
pub description: Option<CowStr<'a>>,
pub description_facets: Option<Vec<Facet<'a>>>,
pub did: Did<'a>,
pub display_name: CowStr<'a>,
pub labels: Option<SelfLabels<'a>>,
pub extra_data: Option<BTreeMap<SmolStr, Data<'a>>>,
}Expand description
Record declaring of the existence of a feed generator, and containing metadata about it. The record can exist in any repository.
Fields
accepts_interactions: Option<bool>Declaration that a feed accepts feedback interactions from a client through app.bsky.feed.sendInteractions
avatar: Option<BlobRef<'a>>content_mode: Option<GeneratorContentMode<'a>>created_at: Datetimedescription: Option<CowStr<'a>>description_facets: Option<Vec<Facet<'a>>>did: Did<'a>display_name: CowStr<'a>labels: Option<SelfLabels<'a>>Self-label values
extra_data: Option<BTreeMap<SmolStr, Data<'a>>>Implementations