SearchPostsBuilder

Struct SearchPostsBuilder 

pub struct SearchPostsBuilder<'a, S: State> { /* private fields */ }
Builder for constructing an instance of this type

Implementations

Source

impl<'a> SearchPostsBuilder<'a, Empty>

pub fn new() -> Self

Create a new builder with all fields unset

Source

impl<'a, S: State> SearchPostsBuilder<'a, S>

pub fn author(self, value: impl Into<Option<AtIdentifier<'a>>>) -> Self

Set the author field (optional)

pub fn maybe_author(self, value: Option<AtIdentifier<'a>>) -> Self

Set the author field to an Option value (optional)

Source

impl<'a, S: State> SearchPostsBuilder<'a, S>

pub fn cursor(self, value: impl Into<Option<CowStr<'a>>>) -> Self

Set the cursor field (optional)

pub fn maybe_cursor(self, value: Option<CowStr<'a>>) -> Self

Set the cursor field to an Option value (optional)

Source

impl<'a, S: State> SearchPostsBuilder<'a, S>

pub fn domain(self, value: impl Into<Option<CowStr<'a>>>) -> Self

Set the domain field (optional)

pub fn maybe_domain(self, value: Option<CowStr<'a>>) -> Self

Set the domain field to an Option value (optional)

Source

impl<'a, S: State> SearchPostsBuilder<'a, S>

pub fn lang(self, value: impl Into<Option<Language>>) -> Self

Set the lang field (optional)

pub fn maybe_lang(self, value: Option<Language>) -> Self

Set the lang field to an Option value (optional)

Source

impl<'a, S: State> SearchPostsBuilder<'a, S>

pub fn limit(self, value: impl Into<Option<i64>>) -> Self

Set the limit field (optional)

pub fn maybe_limit(self, value: Option<i64>) -> Self

Set the limit field to an Option value (optional)

Source

impl<'a, S: State> SearchPostsBuilder<'a, S>

pub fn mentions(self, value: impl Into<Option<AtIdentifier<'a>>>) -> Self

Set the mentions field (optional)

pub fn maybe_mentions(self, value: Option<AtIdentifier<'a>>) -> Self

Set the mentions field to an Option value (optional)

Source

impl<'a, S> SearchPostsBuilder<'a, S>
where S: State, S::Q: IsUnset,

pub fn q(self, value: impl Into<CowStr<'a>>) -> SearchPostsBuilder<'a, SetQ<S>>

Set the q field (required)

Source

impl<'a, S: State> SearchPostsBuilder<'a, S>

pub fn since(self, value: impl Into<Option<CowStr<'a>>>) -> Self

Set the since field (optional)

pub fn maybe_since(self, value: Option<CowStr<'a>>) -> Self

Set the since field to an Option value (optional)

Source

impl<'a, S: State> SearchPostsBuilder<'a, S>

pub fn sort(self, value: impl Into<Option<CowStr<'a>>>) -> Self

Set the sort field (optional)

pub fn maybe_sort(self, value: Option<CowStr<'a>>) -> Self

Set the sort field to an Option value (optional)

Source

impl<'a, S: State> SearchPostsBuilder<'a, S>

pub fn tag(self, value: impl Into<Option<Vec<CowStr<'a>>>>) -> Self

Set the tag field (optional)

pub fn maybe_tag(self, value: Option<Vec<CowStr<'a>>>) -> Self

Set the tag field to an Option value (optional)

Source

impl<'a, S: State> SearchPostsBuilder<'a, S>

pub fn until(self, value: impl Into<Option<CowStr<'a>>>) -> Self

Set the until field (optional)

pub fn maybe_until(self, value: Option<CowStr<'a>>) -> Self

Set the until field to an Option value (optional)

Source

impl<'a, S: State> SearchPostsBuilder<'a, S>

pub fn url(self, value: impl Into<Option<UriValue<'a>>>) -> Self

Set the url field (optional)

pub fn maybe_url(self, value: Option<UriValue<'a>>) -> Self

Set the url field to an Option value (optional)

Source

impl<'a, S> SearchPostsBuilder<'a, S>
where S: State, S::Q: IsSet,

pub fn build(self) -> SearchPosts<'a>

Build the final struct