pub struct FeedViewPost<'a> {
pub feed_context: Option<CowStr<'a>>,
pub post: PostView<'a>,
pub reason: Option<FeedViewPostReason<'a>>,
pub reply: Option<ReplyRef<'a>>,
pub req_id: Option<CowStr<'a>>,
pub extra_data: Option<BTreeMap<SmolStr, Data<'a>>>,
}Fields
feed_context: Option<CowStr<'a>>Context provided by feed generator that may be passed back alongside interactions.
post: PostView<'a>reason: Option<FeedViewPostReason<'a>>reply: Option<ReplyRef<'a>>req_id: Option<CowStr<'a>>Unique identifier per request that may be passed back alongside interactions.
extra_data: Option<BTreeMap<SmolStr, Data<'a>>>Implementations
Sourceimpl<'a> FeedViewPost<'a>
impl<'a> FeedViewPost<'a>
Sourcepub fn new() -> FeedViewPostBuilder<'a, Empty>
pub fn new() -> FeedViewPostBuilder<'a, Empty>
Create a new builder for this type