pub struct GeneratorViewBuilder<'a, S: State> { /* private fields */ }Expand description
Builder for constructing an instance of this type
Implementations
Sourceimpl<'a> GeneratorViewBuilder<'a, Empty>
impl<'a> GeneratorViewBuilder<'a, Empty>
Sourceimpl<'a, S: State> GeneratorViewBuilder<'a, S>
impl<'a, S: State> GeneratorViewBuilder<'a, S>
Sourcepub fn accepts_interactions(self, value: impl Into<Option<bool>>) -> Self
pub fn accepts_interactions(self, value: impl Into<Option<bool>>) -> Self
Set the acceptsInteractions field (optional)
Sourcepub fn maybe_accepts_interactions(self, value: Option<bool>) -> Self
pub fn maybe_accepts_interactions(self, value: Option<bool>) -> Self
Set the acceptsInteractions field to an Option value (optional)
Sourceimpl<'a, S: State> GeneratorViewBuilder<'a, S>
impl<'a, S: State> GeneratorViewBuilder<'a, S>
Sourceimpl<'a, S> GeneratorViewBuilder<'a, S>
impl<'a, S> GeneratorViewBuilder<'a, S>
Sourceimpl<'a, S: State> GeneratorViewBuilder<'a, S>
impl<'a, S: State> GeneratorViewBuilder<'a, S>
Sourcepub fn content_mode(
self,
value: impl Into<Option<GeneratorViewContentMode<'a>>>,
) -> Self
pub fn content_mode( self, value: impl Into<Option<GeneratorViewContentMode<'a>>>, ) -> Self
Set the contentMode field (optional)
Sourcepub fn maybe_content_mode(
self,
value: Option<GeneratorViewContentMode<'a>>,
) -> Self
pub fn maybe_content_mode( self, value: Option<GeneratorViewContentMode<'a>>, ) -> Self
Set the contentMode field to an Option value (optional)
Sourceimpl<'a, S> GeneratorViewBuilder<'a, S>
impl<'a, S> GeneratorViewBuilder<'a, S>
Sourcepub fn creator(
self,
value: impl Into<ProfileView<'a>>,
) -> GeneratorViewBuilder<'a, SetCreator<S>>
pub fn creator( self, value: impl Into<ProfileView<'a>>, ) -> GeneratorViewBuilder<'a, SetCreator<S>>
Set the creator field (required)
Sourceimpl<'a, S: State> GeneratorViewBuilder<'a, S>
impl<'a, S: State> GeneratorViewBuilder<'a, S>
Sourcepub fn description(self, value: impl Into<Option<CowStr<'a>>>) -> Self
pub fn description(self, value: impl Into<Option<CowStr<'a>>>) -> Self
Set the description field (optional)
Sourcepub fn maybe_description(self, value: Option<CowStr<'a>>) -> Self
pub fn maybe_description(self, value: Option<CowStr<'a>>) -> Self
Set the description field to an Option value (optional)
Sourceimpl<'a, S: State> GeneratorViewBuilder<'a, S>
impl<'a, S: State> GeneratorViewBuilder<'a, S>
Sourceimpl<'a, S> GeneratorViewBuilder<'a, S>
impl<'a, S> GeneratorViewBuilder<'a, S>
Sourceimpl<'a, S> GeneratorViewBuilder<'a, S>
impl<'a, S> GeneratorViewBuilder<'a, S>
Sourcepub fn display_name(
self,
value: impl Into<CowStr<'a>>,
) -> GeneratorViewBuilder<'a, SetDisplayName<S>>
pub fn display_name( self, value: impl Into<CowStr<'a>>, ) -> GeneratorViewBuilder<'a, SetDisplayName<S>>
Set the displayName field (required)
Sourceimpl<'a, S> GeneratorViewBuilder<'a, S>
impl<'a, S> GeneratorViewBuilder<'a, S>
Sourcepub fn indexed_at(
self,
value: impl Into<Datetime>,
) -> GeneratorViewBuilder<'a, SetIndexedAt<S>>
pub fn indexed_at( self, value: impl Into<Datetime>, ) -> GeneratorViewBuilder<'a, SetIndexedAt<S>>
Set the indexedAt field (required)
Sourceimpl<'a, S: State> GeneratorViewBuilder<'a, S>
impl<'a, S: State> GeneratorViewBuilder<'a, S>
Sourceimpl<'a, S: State> GeneratorViewBuilder<'a, S>
impl<'a, S: State> GeneratorViewBuilder<'a, S>
Sourcepub fn like_count(self, value: impl Into<Option<i64>>) -> Self
pub fn like_count(self, value: impl Into<Option<i64>>) -> Self
Set the likeCount field (optional)
Sourcepub fn maybe_like_count(self, value: Option<i64>) -> Self
pub fn maybe_like_count(self, value: Option<i64>) -> Self
Set the likeCount field to an Option value (optional)
Sourceimpl<'a, S> GeneratorViewBuilder<'a, S>
impl<'a, S> GeneratorViewBuilder<'a, S>
Sourceimpl<'a, S: State> GeneratorViewBuilder<'a, S>
impl<'a, S: State> GeneratorViewBuilder<'a, S>
Sourcepub fn viewer(self, value: impl Into<Option<GeneratorViewerState<'a>>>) -> Self
pub fn viewer(self, value: impl Into<Option<GeneratorViewerState<'a>>>) -> Self
Set the viewer field (optional)
Sourcepub fn maybe_viewer(self, value: Option<GeneratorViewerState<'a>>) -> Self
pub fn maybe_viewer(self, value: Option<GeneratorViewerState<'a>>) -> Self
Set the viewer field to an Option value (optional)
Sourceimpl<'a, S> GeneratorViewBuilder<'a, S>
impl<'a, S> GeneratorViewBuilder<'a, S>
Sourcepub fn build(self) -> GeneratorView<'a>
pub fn build(self) -> GeneratorView<'a>
Build the final struct
Sourcepub fn build_with_data(
self,
extra_data: BTreeMap<SmolStr, Data<'a>>,
) -> GeneratorView<'a>
pub fn build_with_data( self, extra_data: BTreeMap<SmolStr, Data<'a>>, ) -> GeneratorView<'a>
Build the final struct with custom extra_data