pub struct PostViewBuilder<'a, S: State> { /* private fields */ }Expand description
Builder for constructing an instance of this type
Implementations
Sourceimpl<'a> PostViewBuilder<'a, Empty>
impl<'a> PostViewBuilder<'a, Empty>
Sourceimpl<'a, S> PostViewBuilder<'a, S>
impl<'a, S> PostViewBuilder<'a, S>
Set the author field (required)
Sourceimpl<'a, S: State> PostViewBuilder<'a, S>
impl<'a, S: State> PostViewBuilder<'a, S>
Sourcepub fn bookmark_count(self, value: impl Into<Option<i64>>) -> Self
pub fn bookmark_count(self, value: impl Into<Option<i64>>) -> Self
Set the bookmarkCount field (optional)
Sourcepub fn maybe_bookmark_count(self, value: Option<i64>) -> Self
pub fn maybe_bookmark_count(self, value: Option<i64>) -> Self
Set the bookmarkCount field to an Option value (optional)
Sourceimpl<'a, S> PostViewBuilder<'a, S>
impl<'a, S> PostViewBuilder<'a, S>
Sourceimpl<'a, S: State> PostViewBuilder<'a, S>
impl<'a, S: State> PostViewBuilder<'a, S>
Sourceimpl<'a, S: State> PostViewBuilder<'a, S>
impl<'a, S: State> PostViewBuilder<'a, S>
Sourcepub fn embed(self, value: impl Into<Option<PostViewEmbed<'a>>>) -> Self
pub fn embed(self, value: impl Into<Option<PostViewEmbed<'a>>>) -> Self
Set the embed field (optional)
Sourcepub fn maybe_embed(self, value: Option<PostViewEmbed<'a>>) -> Self
pub fn maybe_embed(self, value: Option<PostViewEmbed<'a>>) -> Self
Set the embed field to an Option value (optional)
Sourceimpl<'a, S> PostViewBuilder<'a, S>
impl<'a, S> PostViewBuilder<'a, S>
Sourcepub fn indexed_at(
self,
value: impl Into<Datetime>,
) -> PostViewBuilder<'a, SetIndexedAt<S>>
pub fn indexed_at( self, value: impl Into<Datetime>, ) -> PostViewBuilder<'a, SetIndexedAt<S>>
Set the indexedAt field (required)
Sourceimpl<'a, S: State> PostViewBuilder<'a, S>
impl<'a, S: State> PostViewBuilder<'a, S>
Sourceimpl<'a, S: State> PostViewBuilder<'a, S>
impl<'a, S: State> PostViewBuilder<'a, S>
Sourcepub fn like_count(self, value: impl Into<Option<i64>>) -> Self
pub fn like_count(self, value: impl Into<Option<i64>>) -> Self
Set the likeCount field (optional)
Sourcepub fn maybe_like_count(self, value: Option<i64>) -> Self
pub fn maybe_like_count(self, value: Option<i64>) -> Self
Set the likeCount field to an Option value (optional)
Sourceimpl<'a, S: State> PostViewBuilder<'a, S>
impl<'a, S: State> PostViewBuilder<'a, S>
Sourcepub fn quote_count(self, value: impl Into<Option<i64>>) -> Self
pub fn quote_count(self, value: impl Into<Option<i64>>) -> Self
Set the quoteCount field (optional)
Sourcepub fn maybe_quote_count(self, value: Option<i64>) -> Self
pub fn maybe_quote_count(self, value: Option<i64>) -> Self
Set the quoteCount field to an Option value (optional)
Sourceimpl<'a, S> PostViewBuilder<'a, S>
impl<'a, S> PostViewBuilder<'a, S>
Sourceimpl<'a, S: State> PostViewBuilder<'a, S>
impl<'a, S: State> PostViewBuilder<'a, S>
Sourcepub fn reply_count(self, value: impl Into<Option<i64>>) -> Self
pub fn reply_count(self, value: impl Into<Option<i64>>) -> Self
Set the replyCount field (optional)
Sourcepub fn maybe_reply_count(self, value: Option<i64>) -> Self
pub fn maybe_reply_count(self, value: Option<i64>) -> Self
Set the replyCount field to an Option value (optional)
Sourceimpl<'a, S: State> PostViewBuilder<'a, S>
impl<'a, S: State> PostViewBuilder<'a, S>
Sourcepub fn repost_count(self, value: impl Into<Option<i64>>) -> Self
pub fn repost_count(self, value: impl Into<Option<i64>>) -> Self
Set the repostCount field (optional)
Sourcepub fn maybe_repost_count(self, value: Option<i64>) -> Self
pub fn maybe_repost_count(self, value: Option<i64>) -> Self
Set the repostCount field to an Option value (optional)
Sourceimpl<'a, S: State> PostViewBuilder<'a, S>
impl<'a, S: State> PostViewBuilder<'a, S>
Sourcepub fn threadgate(self, value: impl Into<Option<ThreadgateView<'a>>>) -> Self
pub fn threadgate(self, value: impl Into<Option<ThreadgateView<'a>>>) -> Self
Set the threadgate field (optional)
Sourcepub fn maybe_threadgate(self, value: Option<ThreadgateView<'a>>) -> Self
pub fn maybe_threadgate(self, value: Option<ThreadgateView<'a>>) -> Self
Set the threadgate field to an Option value (optional)
Sourceimpl<'a, S> PostViewBuilder<'a, S>
impl<'a, S> PostViewBuilder<'a, S>
Sourceimpl<'a, S: State> PostViewBuilder<'a, S>
impl<'a, S: State> PostViewBuilder<'a, S>
Sourcepub fn viewer(self, value: impl Into<Option<ViewerState<'a>>>) -> Self
pub fn viewer(self, value: impl Into<Option<ViewerState<'a>>>) -> Self
Set the viewer field (optional)
Sourcepub fn maybe_viewer(self, value: Option<ViewerState<'a>>) -> Self
pub fn maybe_viewer(self, value: Option<ViewerState<'a>>) -> Self
Set the viewer field to an Option value (optional)