pub struct ListBuilder<St: State, S: BosStr = DefaultStr> { /* private fields */ }Expand description
Builder for constructing an instance of this type.
Implementations
Sourceimpl ListBuilder<Empty, DefaultStr>
impl ListBuilder<Empty, DefaultStr>
Sourceimpl<S: BosStr> ListBuilder<Empty, S>
impl<S: BosStr> ListBuilder<Empty, S>
Sourceimpl<St: State, S: BosStr> ListBuilder<St, S>
impl<St: State, S: BosStr> ListBuilder<St, S>
Sourceimpl<St, S: BosStr> ListBuilder<St, S>
impl<St, S: BosStr> ListBuilder<St, S>
Sourcepub fn created_at(
self,
value: impl Into<Datetime>,
) -> ListBuilder<SetCreatedAt<St>, S>
pub fn created_at( self, value: impl Into<Datetime>, ) -> ListBuilder<SetCreatedAt<St>, S>
Set the createdAt field (required)
Sourceimpl<St: State, S: BosStr> ListBuilder<St, S>
impl<St: State, S: BosStr> ListBuilder<St, S>
Sourcepub fn description(self, value: impl Into<Option<S>>) -> Self
pub fn description(self, value: impl Into<Option<S>>) -> Self
Set the description field (optional)
Sourcepub fn maybe_description(self, value: Option<S>) -> Self
pub fn maybe_description(self, value: Option<S>) -> Self
Set the description field to an Option value (optional)
Sourceimpl<St: State, S: BosStr> ListBuilder<St, S>
impl<St: State, S: BosStr> ListBuilder<St, S>
Sourceimpl<St: State, S: BosStr> ListBuilder<St, S>
impl<St: State, S: BosStr> ListBuilder<St, S>
Sourcepub fn labels(self, value: impl Into<Option<SelfLabels<S>>>) -> Self
pub fn labels(self, value: impl Into<Option<SelfLabels<S>>>) -> Self
Set the labels field (optional)
Sourcepub fn maybe_labels(self, value: Option<SelfLabels<S>>) -> Self
pub fn maybe_labels(self, value: Option<SelfLabels<S>>) -> Self
Set the labels field to an Option value (optional)
Sourceimpl<St, S: BosStr> ListBuilder<St, S>
impl<St, S: BosStr> ListBuilder<St, S>
Sourcepub fn name(self, value: impl Into<S>) -> ListBuilder<SetName<St>, S>
pub fn name(self, value: impl Into<S>) -> ListBuilder<SetName<St>, S>
Set the name field (required)
Sourceimpl<St, S: BosStr> ListBuilder<St, S>
impl<St, S: BosStr> ListBuilder<St, S>
Sourcepub fn purpose(
self,
value: impl Into<ListPurpose<S>>,
) -> ListBuilder<SetPurpose<St>, S>
pub fn purpose( self, value: impl Into<ListPurpose<S>>, ) -> ListBuilder<SetPurpose<St>, S>
Set the purpose field (required)
Sourceimpl<St, S: BosStr> ListBuilder<St, S>
impl<St, S: BosStr> ListBuilder<St, S>