pub struct Verification<'a> {
pub created_at: Datetime,
pub display_name: CowStr<'a>,
pub handle: Handle<'a>,
pub subject: Did<'a>,
pub extra_data: Option<BTreeMap<SmolStr, Data<'a>>>,
}Expand description
Record declaring a verification relationship between two accounts. Verifications are only considered valid by an app if issued by an account the app considers trusted.
Fields
created_at: DatetimeDate of when the verification was created.
display_name: CowStr<'a>Display name of the subject the verification applies to at the moment of verifying, which might not be the same at the time of viewing. The verification is only valid if the current displayName matches the one at the time of verifying.
handle: Handle<'a>Handle of the subject the verification applies to at the moment of verifying, which might not be the same at the time of viewing. The verification is only valid if the current handle matches the one at the time of verifying.
subject: Did<'a>DID of the subject the verification applies to.
extra_data: Option<BTreeMap<SmolStr, Data<'a>>>Implementations
Sourceimpl<'a> Verification<'a>
impl<'a> Verification<'a>
Sourceimpl<'a> Verification<'a>
impl<'a> Verification<'a>
Sourcepub fn new() -> VerificationBuilder<'a, Empty>
pub fn new() -> VerificationBuilder<'a, Empty>
Create a new builder for this type