pub struct CodeBlock<S: BosStr = DefaultStr> {
pub language: Option<S>,
pub plaintext: S,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Fields
language: Option<S>Programming language for syntax highlighting
plaintext: SThe code content
extra_data: Option<BTreeMap<SmolStr, Data<S>>>Trait Implementations
Sourceimpl<'de, S> Deserialize<'de> for CodeBlock<S>where
S: Deserialize<'de> + BosStr,
impl<'de, S> Deserialize<'de> for CodeBlock<S>where
S: Deserialize<'de> + BosStr,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<S: Eq + BosStr> Eq for CodeBlock<S>
Sourceimpl<S: BosStr + IntoStatic> IntoStatic for CodeBlock<S>
impl<S: BosStr + IntoStatic> IntoStatic for CodeBlock<S>
Sourceimpl<S: BosStr> LexiconSchema for CodeBlock<S>
impl<S: BosStr> LexiconSchema for CodeBlock<S>
Sourcefn lexicon_doc() -> LexiconDoc<'static>
fn lexicon_doc() -> LexiconDoc<'static>
Generate the lexicon document for this type Read more
Sourcefn validate(&self) -> Result<(), ConstraintError>
fn validate(&self) -> Result<(), ConstraintError>
Validate an instance against lexicon constraints Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether this type should be inlined vs referenced Read more
Sourceimpl<S: PartialEq + BosStr> PartialEq for CodeBlock<S>
impl<S: PartialEq + BosStr> PartialEq for CodeBlock<S>
impl<S: BosStr> StructuralPartialEq for CodeBlock<S>