pub struct Declaration<S: BosStr = DefaultStr> {
pub allow_group_invites: Option<DeclarationAllowGroupInvites<S>>,
pub allow_incoming: DeclarationAllowIncoming<S>,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Expand description
A declaration of a Bluesky chat account.
Fields
allow_group_invites: Option<DeclarationAllowGroupInvites<S>>[NOTE: This is under active development and should be considered unstable while this note is here]. Declaration about group chat invitation preferences for the record owner.
allow_incoming: DeclarationAllowIncoming<S>extra_data: Option<BTreeMap<SmolStr, Data<S>>>Implementations
Sourceimpl<S: BosStr> Declaration<S>
impl<S: BosStr> Declaration<S>
Sourceimpl Declaration<DefaultStr>
impl Declaration<DefaultStr>
Sourcepub fn new() -> DeclarationBuilder<Empty, DefaultStr>
pub fn new() -> DeclarationBuilder<Empty, DefaultStr>
Create a new builder for this type, using the default string type (DefaultStr = SmolStr) if needed
Sourceimpl<S: BosStr> Declaration<S>
impl<S: BosStr> Declaration<S>
Sourcepub fn builder() -> DeclarationBuilder<Empty, S>
pub fn builder() -> DeclarationBuilder<Empty, S>
Create a new builder for this type