pub struct ProfileViewBasic<S: BosStr = DefaultStr> {
pub associated: Option<ProfileAssociated<S>>,
pub avatar: Option<UriValue<S>>,
pub chat_disabled: Option<bool>,
pub created_at: Option<Datetime>,
pub did: Did<S>,
pub display_name: Option<S>,
pub handle: Handle<S>,
pub kind: Option<ProfileViewBasicKind<S>>,
pub labels: Option<Vec<Label<S>>>,
pub verification: Option<VerificationState<S>>,
pub viewer: Option<ViewerState<S>>,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Fields
associated: Option<ProfileAssociated<S>>avatar: Option<UriValue<S>>chat_disabled: Option<bool>Set to true when the actor cannot actively participate in conversations
created_at: Option<Datetime>did: Did<S>display_name: Option<S>handle: Handle<S>kind: Option<ProfileViewBasicKind<S>>Union field that has data specific to different kinds of convos.
labels: Option<Vec<Label<S>>>verification: Option<VerificationState<S>>viewer: Option<ViewerState<S>>extra_data: Option<BTreeMap<SmolStr, Data<S>>>Implementations
Sourceimpl ProfileViewBasic<DefaultStr>
impl ProfileViewBasic<DefaultStr>
Sourcepub fn new() -> ProfileViewBasicBuilder<Empty, DefaultStr>
pub fn new() -> ProfileViewBasicBuilder<Empty, DefaultStr>
Create a new builder for this type, using the default string type (DefaultStr = SmolStr) if needed
Sourceimpl<S: BosStr> ProfileViewBasic<S>
impl<S: BosStr> ProfileViewBasic<S>
Sourcepub fn builder() -> ProfileViewBasicBuilder<Empty, S>
pub fn builder() -> ProfileViewBasicBuilder<Empty, S>
Create a new builder for this type