pub struct ProfileViewBasicBuilder<St: State, S: BosStr = DefaultStr> { /* private fields */ }Expand description
Builder for constructing an instance of this type.
Implementations
Sourceimpl<S: BosStr> ProfileViewBasicBuilder<Empty, S>
impl<S: BosStr> ProfileViewBasicBuilder<Empty, S>
Sourceimpl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
impl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
Sourcepub fn associated(self, value: impl Into<Option<ProfileAssociated<S>>>) -> Self
pub fn associated(self, value: impl Into<Option<ProfileAssociated<S>>>) -> Self
Set the associated field (optional)
Sourcepub fn maybe_associated(self, value: Option<ProfileAssociated<S>>) -> Self
pub fn maybe_associated(self, value: Option<ProfileAssociated<S>>) -> Self
Set the associated field to an Option value (optional)
Sourceimpl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
impl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
Sourceimpl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
impl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
Sourcepub fn chat_disabled(self, value: impl Into<Option<bool>>) -> Self
pub fn chat_disabled(self, value: impl Into<Option<bool>>) -> Self
Set the chatDisabled field (optional)
Sourcepub fn maybe_chat_disabled(self, value: Option<bool>) -> Self
pub fn maybe_chat_disabled(self, value: Option<bool>) -> Self
Set the chatDisabled field to an Option value (optional)
Sourceimpl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
impl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
Sourcepub fn created_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn created_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the createdAt field (optional)
Sourcepub fn maybe_created_at(self, value: Option<Datetime>) -> Self
pub fn maybe_created_at(self, value: Option<Datetime>) -> Self
Set the createdAt field to an Option value (optional)
Sourceimpl<St, S: BosStr> ProfileViewBasicBuilder<St, S>
impl<St, S: BosStr> ProfileViewBasicBuilder<St, S>
Sourceimpl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
impl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
Sourcepub fn display_name(self, value: impl Into<Option<S>>) -> Self
pub fn display_name(self, value: impl Into<Option<S>>) -> Self
Set the displayName field (optional)
Sourcepub fn maybe_display_name(self, value: Option<S>) -> Self
pub fn maybe_display_name(self, value: Option<S>) -> Self
Set the displayName field to an Option value (optional)
Sourceimpl<St, S: BosStr> ProfileViewBasicBuilder<St, S>
impl<St, S: BosStr> ProfileViewBasicBuilder<St, S>
Sourceimpl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
impl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
Sourcepub fn kind(self, value: impl Into<Option<ProfileViewBasicKind<S>>>) -> Self
pub fn kind(self, value: impl Into<Option<ProfileViewBasicKind<S>>>) -> Self
Set the kind field (optional)
Sourcepub fn maybe_kind(self, value: Option<ProfileViewBasicKind<S>>) -> Self
pub fn maybe_kind(self, value: Option<ProfileViewBasicKind<S>>) -> Self
Set the kind field to an Option value (optional)
Sourceimpl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
impl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
Sourceimpl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
impl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
Sourcepub fn verification(
self,
value: impl Into<Option<VerificationState<S>>>,
) -> Self
pub fn verification( self, value: impl Into<Option<VerificationState<S>>>, ) -> Self
Set the verification field (optional)
Sourcepub fn maybe_verification(self, value: Option<VerificationState<S>>) -> Self
pub fn maybe_verification(self, value: Option<VerificationState<S>>) -> Self
Set the verification field to an Option value (optional)
Sourceimpl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
impl<St: State, S: BosStr> ProfileViewBasicBuilder<St, S>
Sourcepub fn viewer(self, value: impl Into<Option<ViewerState<S>>>) -> Self
pub fn viewer(self, value: impl Into<Option<ViewerState<S>>>) -> Self
Set the viewer field (optional)
Sourcepub fn maybe_viewer(self, value: Option<ViewerState<S>>) -> Self
pub fn maybe_viewer(self, value: Option<ViewerState<S>>) -> Self
Set the viewer field to an Option value (optional)
Sourceimpl<St, S: BosStr> ProfileViewBasicBuilder<St, S>
impl<St, S: BosStr> ProfileViewBasicBuilder<St, S>
Sourcepub fn build(self) -> ProfileViewBasic<S>
pub fn build(self) -> ProfileViewBasic<S>
Build the final struct.
Sourcepub fn build_with_data(
self,
extra_data: BTreeMap<SmolStr, Data<S>>,
) -> ProfileViewBasic<S>
pub fn build_with_data( self, extra_data: BTreeMap<SmolStr, Data<S>>, ) -> ProfileViewBasic<S>
Build the final struct with custom extra_data.