pub struct LogCreateJoinLink<S: BosStr = DefaultStr> {
pub convo_id: S,
pub message: SystemMessageView<S>,
pub rev: S,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Expand description
[NOTE: This is under active development and should be considered unstable while this note is here]. Event indicating a join link was created for a group convo.
Fields
convo_id: Smessage: SystemMessageView<S>A system message with data of type #systemMessageDataCreateJoinLink
rev: Sextra_data: Option<BTreeMap<SmolStr, Data<S>>>Implementations
Sourceimpl LogCreateJoinLink<DefaultStr>
impl LogCreateJoinLink<DefaultStr>
Sourcepub fn new() -> LogCreateJoinLinkBuilder<Empty, DefaultStr>
pub fn new() -> LogCreateJoinLinkBuilder<Empty, DefaultStr>
Create a new builder for this type, using the default string type (DefaultStr = SmolStr) if needed
Sourceimpl<S: BosStr> LogCreateJoinLink<S>
impl<S: BosStr> LogCreateJoinLink<S>
Sourcepub fn builder() -> LogCreateJoinLinkBuilder<Empty, S>
pub fn builder() -> LogCreateJoinLinkBuilder<Empty, S>
Create a new builder for this type