pub struct MessageView<S: BosStr = DefaultStr> {
pub embed: Option<MessageViewEmbed<S>>,
pub facets: Option<Vec<Facet<S>>>,
pub id: S,
pub reactions: Option<Vec<ReactionView<S>>>,
pub reply_to: Option<MessageViewReplyTo<S>>,
pub rev: S,
pub sender: MessageViewSender<S>,
pub sent_at: Datetime,
pub text: S,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Fields
embed: Option<MessageViewEmbed<S>>facets: Option<Vec<Facet<S>>>Annotations of text (mentions, URLs, hashtags, etc)
id: Sreactions: Option<Vec<ReactionView<S>>>Reactions to this message, in ascending order of creation time.
reply_to: Option<MessageViewReplyTo<S>>If set, the message this message is replying to. The full view of the referenced message is embedded so the client can render it inline. Only a single level is embedded: the embedded message will not itself have a populated ‘replyTo’ field even if it was also a reply.
rev: Ssender: MessageViewSender<S>sent_at: Datetimetext: Sextra_data: Option<BTreeMap<SmolStr, Data<S>>>Implementations
Sourceimpl MessageView<DefaultStr>
impl MessageView<DefaultStr>
Sourcepub fn new() -> MessageViewBuilder<Empty, DefaultStr>
pub fn new() -> MessageViewBuilder<Empty, DefaultStr>
Create a new builder for this type, using the default string type (DefaultStr = SmolStr) if needed
Sourceimpl<S: BosStr> MessageView<S>
impl<S: BosStr> MessageView<S>
Sourcepub fn builder() -> MessageViewBuilder<Empty, S>
pub fn builder() -> MessageViewBuilder<Empty, S>
Create a new builder for this type