pub struct SystemMessageDataEnableJoinLink<S: BosStr = DefaultStr> {
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Expand description
[NOTE: This is under active development and should be considered unstable while this note is here]. System message indicating the group join link was enabled.
Fields
extra_data: Option<BTreeMap<SmolStr, Data<S>>>Trait Implementations
Sourceimpl<S: Clone + BosStr> Clone for SystemMessageDataEnableJoinLink<S>
impl<S: Clone + BosStr> Clone for SystemMessageDataEnableJoinLink<S>
Sourcefn clone(&self) -> SystemMessageDataEnableJoinLink<S>
fn clone(&self) -> SystemMessageDataEnableJoinLink<S>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<S: Default + BosStr> Default for SystemMessageDataEnableJoinLink<S>
impl<S: Default + BosStr> Default for SystemMessageDataEnableJoinLink<S>
Sourcefn default() -> SystemMessageDataEnableJoinLink<S>
fn default() -> SystemMessageDataEnableJoinLink<S>
Returns the “default value” for a type. Read more
Sourceimpl<'de, S> Deserialize<'de> for SystemMessageDataEnableJoinLink<S>where
S: Deserialize<'de> + BosStr,
impl<'de, S> Deserialize<'de> for SystemMessageDataEnableJoinLink<S>where
S: Deserialize<'de> + BosStr,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<S: Eq + BosStr> Eq for SystemMessageDataEnableJoinLink<S>
Sourceimpl<S: BosStr + IntoStatic> IntoStatic for SystemMessageDataEnableJoinLink<S>
impl<S: BosStr + IntoStatic> IntoStatic for SystemMessageDataEnableJoinLink<S>
Sourcetype Output = SystemMessageDataEnableJoinLink<<S as IntoStatic>::Output>
type Output = SystemMessageDataEnableJoinLink<<S as IntoStatic>::Output>
The “owned” variant of the type. For
Cow<'a, str>, this is Cow<'static, str>, for example.Sourcefn into_static(self) -> Self::Output
fn into_static(self) -> Self::Output
Turns the value into an “owned” variant, which can then be returned, moved, etc. Read more
Sourceimpl<S: BosStr> LexiconSchema for SystemMessageDataEnableJoinLink<S>
impl<S: BosStr> LexiconSchema for SystemMessageDataEnableJoinLink<S>
Sourcefn lexicon_doc() -> LexiconDoc<'static>
fn lexicon_doc() -> LexiconDoc<'static>
Generate the lexicon document for this type Read more
Sourcefn validate(&self) -> Result<(), ConstraintError>
fn validate(&self) -> Result<(), ConstraintError>
Validate an instance against lexicon constraints Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether this type should be inlined vs referenced Read more
Sourceimpl<S: PartialEq + BosStr> PartialEq for SystemMessageDataEnableJoinLink<S>
impl<S: PartialEq + BosStr> PartialEq for SystemMessageDataEnableJoinLink<S>
Sourcefn eq(&self, other: &SystemMessageDataEnableJoinLink<S>) -> bool
fn eq(&self, other: &SystemMessageDataEnableJoinLink<S>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<S> Serialize for SystemMessageDataEnableJoinLink<S>
impl<S> Serialize for SystemMessageDataEnableJoinLink<S>
impl<S: BosStr> StructuralPartialEq for SystemMessageDataEnableJoinLink<S>