pub enum SubscribeModEventsError {
FutureCursor(Option<SmolStr>),
ConsumerTooSlow(Option<SmolStr>),
Other {
error: SmolStr,
message: Option<SmolStr>,
},
}Variants
FutureCursor(Option<SmolStr>)
ConsumerTooSlow(Option<SmolStr>)
If the consumer of the stream can not keep up with events, and a backlog gets too large, the server will drop the connection.
Other
Catch-all for unknown error codes.