pub enum RefreshIdentityError<'a> {
HandleNotFound(Option<CowStr<'a>>),
DidNotFound(Option<CowStr<'a>>),
DidDeactivated(Option<CowStr<'a>>),
Unknown(Data<'a>),
}Variants
HandleNotFound(Option<CowStr<'a>>)
The resolution process confirmed that the handle does not resolve to any DID.
DidNotFound(Option<CowStr<'a>>)
The DID resolution process confirmed that there is no current DID.
DidDeactivated(Option<CowStr<'a>>)
The DID previously existed, but has been deactivated.
Unknown(Data<'a>)