pub struct LabelValueDefinition<S: BosStr = DefaultStr> {
pub adult_only: Option<bool>,
pub blurs: LabelValueDefinitionBlurs<S>,
pub default_setting: Option<LabelValueDefinitionDefaultSetting<S>>,
pub identifier: S,
pub locales: Vec<LabelValueDefinitionStrings<S>>,
pub severity: LabelValueDefinitionSeverity<S>,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Expand description
Declares a label value and its expected interpretations and behaviors.
Fields
adult_only: Option<bool>Does the user need to have adult content enabled in order to configure this label?
blurs: LabelValueDefinitionBlurs<S>What should this label hide in the UI, if applied? ‘content’ hides all of the target; ‘media’ hides the images/video/audio; ‘none’ hides nothing.
default_setting: Option<LabelValueDefinitionDefaultSetting<S>>The default setting for this label.
identifier: SThe value of the label being defined. Must only include lowercase ascii and the ‘-’ character ([a-z-]+).
locales: Vec<LabelValueDefinitionStrings<S>>severity: LabelValueDefinitionSeverity<S>How should a client visually convey this label? ‘inform’ means neutral and informational; ‘alert’ means negative and warning; ‘none’ means show nothing.
extra_data: Option<BTreeMap<SmolStr, Data<S>>>Implementations
Sourceimpl LabelValueDefinition<DefaultStr>
impl LabelValueDefinition<DefaultStr>
Sourcepub fn new() -> LabelValueDefinitionBuilder<Empty, DefaultStr>
pub fn new() -> LabelValueDefinitionBuilder<Empty, DefaultStr>
Create a new builder for this type, using the default string type (DefaultStr = SmolStr) if needed
Sourceimpl<S: BosStr> LabelValueDefinition<S>
impl<S: BosStr> LabelValueDefinition<S>
Sourcepub fn builder() -> LabelValueDefinitionBuilder<Empty, S>
pub fn builder() -> LabelValueDefinitionBuilder<Empty, S>
Create a new builder for this type