pub struct ContributionPatch<S: BosStr = DefaultStr> {
pub changes: Data<S>,
pub contribution: StrongRef<S>,
pub contribution_review: StrongRef<S>,
pub created_at: Datetime,
pub subject: Option<AtUri<S>>,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Expand description
A mod-approved patch representing changes to apply to an entity. Created on mod approval, deleted when the entity owner accepts and merges.
Fields
changes: Data<S>The approved changes to overlay on the entity.
contribution: StrongRef<S>contribution_review: StrongRef<S>created_at: Datetimesubject: Option<AtUri<S>>The entity these changes apply to. Absent for newGame contributions.
extra_data: Option<BTreeMap<SmolStr, Data<S>>>Implementations
Sourceimpl<S: BosStr> ContributionPatch<S>
impl<S: BosStr> ContributionPatch<S>
Sourceimpl ContributionPatch<DefaultStr>
impl ContributionPatch<DefaultStr>
Sourcepub fn new() -> ContributionPatchBuilder<Empty, DefaultStr>
pub fn new() -> ContributionPatchBuilder<Empty, DefaultStr>
Create a new builder for this type, using the default string type (DefaultStr = SmolStr) if needed
Sourceimpl<S: BosStr> ContributionPatch<S>
impl<S: BosStr> ContributionPatch<S>
Sourcepub fn builder() -> ContributionPatchBuilder<Empty, S>
pub fn builder() -> ContributionPatchBuilder<Empty, S>
Create a new builder for this type