pub struct Stats<'a> {
pub daily_rewards_claimed: Option<i64>,
pub items_collected: Option<i64>,
pub last_post_read_date: Option<Datetime>,
pub posts_read_today: Option<i64>,
pub posts_read_total: Option<i64>,
pub posts_viewed: Option<i64>,
pub shuffles_performed: Option<i64>,
pub specimens_collected: Option<i64>,
pub extra_data: Option<BTreeMap<SmolStr, Data<'a>>>,
}Expand description
Game-specific statistics and metrics
Fields
daily_rewards_claimed: Option<i64>Total daily rewards claimed
items_collected: Option<i64>Total items collected
last_post_read_date: Option<Datetime>Date when posts read today was last updated (for daily reset tracking)
posts_read_today: Option<i64>Posts read today (resets daily)
posts_read_total: Option<i64>Total posts read (all time, cumulative)
posts_viewed: Option<i64>Total posts viewed
shuffles_performed: Option<i64>Total shuffles performed
specimens_collected: Option<i64>Total specimens collected
extra_data: Option<BTreeMap<SmolStr, Data<'a>>>Trait Implementations
Sourceimpl<'de: 'a, 'a> Deserialize<'de> for Stats<'a>
impl<'de: 'a, 'a> Deserialize<'de> for Stats<'a>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> IntoStatic for Stats<'a>
impl<'a> IntoStatic for Stats<'a>
Sourceimpl<'a> LexiconSchema for Stats<'a>
impl<'a> LexiconSchema for Stats<'a>
Sourcefn lexicon_doc() -> LexiconDoc<'static>
fn lexicon_doc() -> LexiconDoc<'static>
Generate the lexicon document for this type Read more
Sourcefn validate(&self) -> Result<(), ConstraintError>
fn validate(&self) -> Result<(), ConstraintError>
Validate an instance against lexicon constraints Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether this type should be inlined vs referenced Read more
impl<'a> Eq for Stats<'a>
impl<'a> StructuralPartialEq for Stats<'a>