BehaviorSettings

Struct BehaviorSettings 

pub struct BehaviorSettings<'a> {
Show 50 fields pub animation_timing: Option<AnimationTiming<'a>>, pub anisota_only_mode: Option<bool>, pub audio_enabled: Option<bool>, pub batch_notification_types: Option<BatchNotificationTypes<'a>>, pub batch_notifications: Option<bool>, pub bypass_detached_quotes: Option<bool>, pub combine_relationship_and_follower_filters: Option<bool>, pub confirm_deletes: Option<bool>, pub confirm_draft_saves: Option<bool>, pub default_home_page: Option<CowStr<'a>>, pub default_post_target: Option<CowStr<'a>>, pub feed_cache_length: Option<i64>, pub filter_by_follower_ratio: Option<bool>, pub filter_notification_types: Option<FilterNotificationTypes<'a>>, pub filter_notifications_by_followers: Option<bool>, pub filter_notifications_by_relationship: Option<bool>, pub filter_relationship_types: Option<FilterRelationshipTypes<'a>>, pub force_chronological_sort: Option<bool>, pub fullscreen_behavior: Option<CowStr<'a>>, pub hide_interacted_posts: Option<bool>, pub hide_notification_count: Option<bool>, pub hide_read_posts: Option<bool>, pub hide_reposts: Option<HideReposts<'a>>, pub highlight_by_follower_ratio: Option<bool>, pub highlight_max_follower_count: Option<i64>, pub highlight_min_follower_count: Option<CowStr<'a>>, pub highlight_min_follower_ratio: Option<CowStr<'a>>, pub highlight_notification_types: Option<HighlightNotificationTypes<'a>>, pub highlight_notifications: Option<bool>, pub include_reply_engagement: Option<bool>, pub keyboard_shortcuts: Option<KeyboardShortcuts<'a>>, pub max_follower_count: Option<i64>, pub min_follower_count: Option<CowStr<'a>>, pub min_follower_ratio: Option<CowStr<'a>>, pub moderation_settings: Option<ModerationSettings<'a>>, pub post_drafts: Option<bool>, pub reverse_feed_order: Option<bool>, pub show_blocked_posts: Option<bool>, pub show_new_highlights_section: Option<bool>, pub show_notification_sections: Option<bool>, pub show_older_section: Option<bool>, pub show_rarity_in_header: Option<bool>, pub show_recently_read_section: Option<bool>, pub show_thread_suggestion: Option<bool>, pub show_unread_section: Option<bool>, pub soundscape: Option<CowStr<'a>>, pub stats_visible_sections: Option<StatsVisibleSections<'a>>, pub text_only_mode: Option<bool>, pub track_read_posts: Option<bool>, pub extra_data: Option<BTreeMap<SmolStr, Data<'a>>>,
}
App behavior and functionality settings

Fields

animation_timing: Option<AnimationTiming<'a>>anisota_only_mode: Option<bool>

Show only Anisota posts in profiles instead of regular Bluesky posts

audio_enabled: Option<bool>

Whether background audio/soundscapes are enabled by default

batch_notification_types: Option<BatchNotificationTypes<'a>>batch_notifications: Option<bool>

Group similar notifications together

bypass_detached_quotes: Option<bool>

Bypass detached quotes to see the full content that was removed by the author

combine_relationship_and_follower_filters: Option<bool>

When enabled, show notifications that match either relationship OR follower count filters

confirm_deletes: Option<bool>

Show confirmation before deleting

confirm_draft_saves: Option<bool>

Show warning before saving drafts

default_home_page: Option<CowStr<'a>>

Default page to show on app load

default_post_target: Option<CowStr<'a>>

Default publishing target for new posts

feed_cache_length: Option<i64>

How long to cache feed position in minutes (30, 60, 360, 720, 1440, 10080)

filter_by_follower_ratio: Option<bool>

Filter by follower to following ratio

filter_notification_types: Option<FilterNotificationTypes<'a>>filter_notifications_by_followers: Option<bool>

Filter notifications by follower count

filter_notifications_by_relationship: Option<bool>

Filter notifications based on relationship with the author

filter_relationship_types: Option<FilterRelationshipTypes<'a>>force_chronological_sort: Option<bool>

Force chronological sorting of posts

fullscreen_behavior: Option<CowStr<'a>>

Fullscreen behavior mode: fullscreen (show control row), immersive (hide all UI), or cycle (cycle through states)

hide_interacted_posts: Option<bool>

Hide posts that have been liked or reposted to focus on new content

hide_notification_count: Option<bool>

Hide the exact notification count in the corner element, always showing ‘notifications’ instead

hide_read_posts: Option<bool>

Hide posts that have been read

hide_reposts: Option<HideReposts<'a>>highlight_by_follower_ratio: Option<bool>

Also require a minimum follower-to-following ratio for highlighting

highlight_max_follower_count: Option<i64>

Maximum follower count for notification highlighting

highlight_min_follower_count: Option<CowStr<'a>>

Minimum follower count for notification highlighting (stored as string or integer)

highlight_min_follower_ratio: Option<CowStr<'a>>

Minimum follower-to-following ratio for highlighting (stored as string)

highlight_notification_types: Option<HighlightNotificationTypes<'a>>highlight_notifications: Option<bool>

Enable notification highlighting to surface important notifications from notable accounts

include_reply_engagement: Option<bool>

Include engagement metrics from reply posts in stats calculations

keyboard_shortcuts: Option<KeyboardShortcuts<'a>>max_follower_count: Option<i64>

Maximum follower count for notification filtering

min_follower_count: Option<CowStr<'a>>

Minimum follower count for notification filtering (stored as string)

min_follower_ratio: Option<CowStr<'a>>

Minimum follower ratio for filtering (stored as string)

moderation_settings: Option<ModerationSettings<'a>>post_drafts: Option<bool>

Enable post drafts feature

reverse_feed_order: Option<bool>

Show newest posts first

show_blocked_posts: Option<bool>

Show content from users you have blocked

show_new_highlights_section: Option<bool>

Show New Highlights section in notifications

show_notification_sections: Option<bool>

Enable notification sections (New Highlights, Unread, Recently Read, Older)

show_older_section: Option<bool>

Show Older section in notifications

show_rarity_in_header: Option<bool>

Display rarity indicator and rate in the stats modal header

show_recently_read_section: Option<bool>

Show Recently Read section in notifications

show_thread_suggestion: Option<bool>

Show thread suggestion when typing beyond character limit in post composer

show_unread_section: Option<bool>

Show Unread section in notifications

soundscape: Option<CowStr<'a>>

Selected background audio soundscape

stats_visible_sections: Option<StatsVisibleSections<'a>>text_only_mode: Option<bool>

Filter out posts with images and videos for distraction-free reading

track_read_posts: Option<bool>

Track which posts have been read

extra_data: Option<BTreeMap<SmolStr, Data<'a>>>