pub struct ControlSettings<'a> {Show 29 fields
pub account_list: Option<bool>,
pub back: Option<bool>,
pub comment_button: Option<bool>,
pub copy_author_did: Option<bool>,
pub copy_button: Option<bool>,
pub copy_post_link: Option<bool>,
pub copy_post_text: Option<bool>,
pub delete: Option<bool>,
pub engage_button: Option<bool>,
pub feed_switcher: Option<bool>,
pub fetch: Option<bool>,
pub flip: Option<bool>,
pub forward: Option<bool>,
pub fullscreen: Option<bool>,
pub leaflet_publications: Option<bool>,
pub like: Option<bool>,
pub list: Option<bool>,
pub multi_engage_button: Option<bool>,
pub multi_repost_button: Option<bool>,
pub position_button: Option<bool>,
pub post_list: Option<bool>,
pub quick_access: Option<bool>,
pub quote: Option<bool>,
pub relationship_button: Option<bool>,
pub reply: Option<bool>,
pub repost: Option<bool>,
pub shuffle: Option<bool>,
pub text_only_mode: Option<bool>,
pub extra_data: Option<BTreeMap<SmolStr, Data<'a>>>,
}Expand description
Control button visibility settings
Fields
account_list: Option<bool>Show account list button
back: Option<bool>Show back button
Show expandable comment button
Show copy author DID button
Show expandable copy button
copy_post_link: Option<bool>Show copy post link button
copy_post_text: Option<bool>Show copy post text button
delete: Option<bool>Show delete button
Show expandable engage button
feed_switcher: Option<bool>Show feed switcher button
fetch: Option<bool>Show fetch button
flip: Option<bool>Show flip button
forward: Option<bool>Show forward button
fullscreen: Option<bool>Show fullscreen button
leaflet_publications: Option<bool>Show leaflet publications button
like: Option<bool>Show like button
list: Option<bool>Show list button
Show expandable multi-engage button
Show expandable multi-repost button
Show position button
post_list: Option<bool>Show post list button
quick_access: Option<bool>Show quick access button
quote: Option<bool>Show quote button
Show relationship button
reply: Option<bool>Show reply button
repost: Option<bool>Show repost button
shuffle: Option<bool>Show shuffle button
text_only_mode: Option<bool>Show text only mode button
extra_data: Option<BTreeMap<SmolStr, Data<'a>>>Trait Implementations
Sourceimpl<'a> Clone for ControlSettings<'a>
impl<'a> Clone for ControlSettings<'a>
Sourcefn clone(&self) -> ControlSettings<'a>
fn clone(&self) -> ControlSettings<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for ControlSettings<'a>
impl<'a> Debug for ControlSettings<'a>
Sourceimpl<'a> Default for ControlSettings<'a>
impl<'a> Default for ControlSettings<'a>
Sourcefn default() -> ControlSettings<'a>
fn default() -> ControlSettings<'a>
Returns the “default value” for a type. Read more
Sourceimpl<'de: 'a, 'a> Deserialize<'de> for ControlSettings<'a>
impl<'de: 'a, 'a> Deserialize<'de> for ControlSettings<'a>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> IntoStatic for ControlSettings<'a>
impl<'a> IntoStatic for ControlSettings<'a>
Sourcetype Output = ControlSettings<'static>
type Output = ControlSettings<'static>
The “owned” variant of the type. For
Cow<'a, str>, this is Cow<'static, str>, for example.Sourcefn into_static(self) -> Self::Output
fn into_static(self) -> Self::Output
Turns the value into an “owned” variant, which can then be returned, moved, etc. Read more
Sourceimpl<'a> LexiconSchema for ControlSettings<'a>
impl<'a> LexiconSchema for ControlSettings<'a>
Sourcefn lexicon_doc() -> LexiconDoc<'static>
fn lexicon_doc() -> LexiconDoc<'static>
Generate the lexicon document for this type Read more
Sourcefn validate(&self) -> Result<(), ConstraintError>
fn validate(&self) -> Result<(), ConstraintError>
Validate an instance against lexicon constraints Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether this type should be inlined vs referenced Read more
Sourceimpl<'a> PartialEq for ControlSettings<'a>
impl<'a> PartialEq for ControlSettings<'a>
Sourceimpl<'a> Serialize for ControlSettings<'a>
impl<'a> Serialize for ControlSettings<'a>
impl<'a> Eq for ControlSettings<'a>
impl<'a> StructuralPartialEq for ControlSettings<'a>