pub struct StatsOutput<S: BosStr = DefaultStr> {
pub collection_stats: Vec<CollectionStats<S>>,
pub collections: Vec<Nsid<S>>,
pub total_actors: i64,
pub total_lexicons: i64,
pub total_records: i64,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Fields
collection_stats: Vec<CollectionStats<S>>Per-collection statistics
collections: Vec<Nsid<S>>List of collection NSIDs indexed in this slice
total_actors: i64Total number of unique actors indexed in this slice
total_lexicons: i64Total number of lexicons defined for this slice
total_records: i64Total number of records indexed in this slice
extra_data: Option<BTreeMap<SmolStr, Data<S>>>Trait Implementations
Sourceimpl<S: Clone + BosStr> Clone for StatsOutput<S>
impl<S: Clone + BosStr> Clone for StatsOutput<S>
Sourcefn clone(&self) -> StatsOutput<S>
fn clone(&self) -> StatsOutput<S>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de, S> Deserialize<'de> for StatsOutput<S>where
S: Deserialize<'de> + BosStr,
impl<'de, S> Deserialize<'de> for StatsOutput<S>where
S: Deserialize<'de> + BosStr,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<S: Eq + BosStr> Eq for StatsOutput<S>
Sourceimpl<S: BosStr + IntoStatic> IntoStatic for StatsOutput<S>
impl<S: BosStr + IntoStatic> IntoStatic for StatsOutput<S>
Sourcetype Output = StatsOutput<<S as IntoStatic>::Output>
type Output = StatsOutput<<S as IntoStatic>::Output>
The “owned” variant of the type. For
Cow<'a, str>, this is Cow<'static, str>, for example.Sourcefn into_static(self) -> Self::Output
fn into_static(self) -> Self::Output
Turns the value into an “owned” variant, which can then be returned, moved, etc. Read more
Sourceimpl<S: PartialEq + BosStr> PartialEq for StatsOutput<S>
impl<S: PartialEq + BosStr> PartialEq for StatsOutput<S>
Sourcefn eq(&self, other: &StatsOutput<S>) -> bool
fn eq(&self, other: &StatsOutput<S>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<S> Serialize for StatsOutput<S>
impl<S> Serialize for StatsOutput<S>
impl<S: BosStr> StructuralPartialEq for StatsOutput<S>