pub struct SliceView<S: BosStr = DefaultStr> {Show 13 fields
pub cid: Cid<S>,
pub created_at: Datetime,
pub creator: ProfileViewBasic<S>,
pub domain: S,
pub indexed_actor_count: Option<i64>,
pub indexed_collection_count: Option<i64>,
pub indexed_record_count: Option<i64>,
pub name: S,
pub sparkline: Option<Vec<SparklinePoint<S>>>,
pub uri: AtUri<S>,
pub waitlist_invite_count: Option<i64>,
pub waitlist_request_count: Option<i64>,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Fields
cid: Cid<S>created_at: Datetimecreator: ProfileViewBasic<S>Profile of the slice creator
domain: SPrimary domain namespace for this slice (e.g. social.grain)
indexed_actor_count: Option<i64>Total number of unique indexed actors in this slice
indexed_collection_count: Option<i64>Number of collections with indexed records
indexed_record_count: Option<i64>Total number of indexed records in this slice
name: SDisplay name of the slice
sparkline: Option<Vec<SparklinePoint<S>>>Recent activity sparkline data points for the last 24 hours
uri: AtUri<S>waitlist_invite_count: Option<i64>Total number of waitlist invites for this slice
waitlist_request_count: Option<i64>Total number of waitlist requests for this slice
extra_data: Option<BTreeMap<SmolStr, Data<S>>>Implementations
Sourceimpl SliceView<DefaultStr>
impl SliceView<DefaultStr>
Sourcepub fn new() -> SliceViewBuilder<Empty, DefaultStr>
pub fn new() -> SliceViewBuilder<Empty, DefaultStr>
Create a new builder for this type, using the default string type (DefaultStr = SmolStr) if needed