pub trait State: Sealed {
type Blocks;
type Slug;
type CreatedAt;
type Title;
}Expand description
State trait tracking which required fields have been set
pub trait State: Sealed {
type Blocks;
type Slug;
type CreatedAt;
type Title;
}State trait tracking which required fields have been set