pub struct Quote<S: BosStr = DefaultStr> {
pub facets: Option<Vec<Facet<S>>>,
pub text: S,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Expand description
A blockquote with optional inline formatting
Fields
facets: Option<Vec<Facet<S>>>text: Sextra_data: Option<BTreeMap<SmolStr, Data<S>>>Trait Implementations
Sourceimpl<'de, S> Deserialize<'de> for Quote<S>where
S: Deserialize<'de> + BosStr,
impl<'de, S> Deserialize<'de> for Quote<S>where
S: Deserialize<'de> + BosStr,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<S: Eq + BosStr> Eq for Quote<S>
Sourceimpl<S: BosStr + IntoStatic> IntoStatic for Quote<S>
impl<S: BosStr + IntoStatic> IntoStatic for Quote<S>
Sourceimpl<S: BosStr> LexiconSchema for Quote<S>
impl<S: BosStr> LexiconSchema for Quote<S>
Sourcefn lexicon_doc() -> LexiconDoc<'static>
fn lexicon_doc() -> LexiconDoc<'static>
Generate the lexicon document for this type Read more
Sourcefn validate(&self) -> Result<(), ConstraintError>
fn validate(&self) -> Result<(), ConstraintError>
Validate an instance against lexicon constraints Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether this type should be inlined vs referenced Read more
impl<S: BosStr> StructuralPartialEq for Quote<S>