pub struct Origin<'a> {
pub broadcaster: Option<Did<'a>>,
pub iroh_ticket: Option<CowStr<'a>>,
pub server: Did<'a>,
pub streamer: Did<'a>,
pub updated_at: Datetime,
pub websocket_url: Option<UriValue<'a>>,
pub extra_data: Option<BTreeMap<SmolStr, Data<'a>>>,
}Expand description
Record indicating a livestream is published and available for replication at a given address. By convention, the record key is streamer::server
Fields
broadcaster: Option<Did<'a>>did of the broadcaster that operates the server syndicating the livestream
iroh_ticket: Option<CowStr<'a>>Iroh ticket that can be used to access the livestream from the server
server: Did<'a>did of the server that’s currently rebroadcasting the livestream
streamer: Did<'a>DID of the streamer whose livestream is being published
updated_at: DatetimePeriodically updated timestamp when this origin last saw a livestream
websocket_url: Option<UriValue<'a>>URL of the websocket endpoint for the livestream
extra_data: Option<BTreeMap<SmolStr, Data<'a>>>Implementations