pub struct Key<S: BosStr = DefaultStr> {
pub created_at: Datetime,
pub created_by: Option<S>,
pub signing_key: S,
pub extra_data: Option<BTreeMap<SmolStr, Data<S>>>,
}Expand description
Record linking an atproto identity with a stream signing key
Fields
created_at: DatetimeClient-declared timestamp when this key was created.
created_by: Option<S>The name of the client that created this key.
signing_key: SThe did:key signing key for the stream.
extra_data: Option<BTreeMap<SmolStr, Data<S>>>Implementations
Sourceimpl Key<DefaultStr>
impl Key<DefaultStr>
Sourcepub fn new() -> KeyBuilder<Empty, DefaultStr>
pub fn new() -> KeyBuilder<Empty, DefaultStr>
Create a new builder for this type, using the default string type (DefaultStr = SmolStr) if needed