pub enum DeleteBlockError<'a> {
Unauthorized(Option<CowStr<'a>>),
Forbidden(Option<CowStr<'a>>),
SessionNotFound(Option<CowStr<'a>>),
Unknown(Data<'a>),
}Variants
The request lacks valid authentication credentials.
Forbidden(Option<CowStr<'a>>)
The caller does not have permission to delete blocks for this streamer.
SessionNotFound(Option<CowStr<'a>>)
The streamer’s OAuth session could not be found or is invalid.
Unknown(Data<'a>)