SegmentBuilder

Struct SegmentBuilder 

pub struct SegmentBuilder<'a, S: State> { /* private fields */ }
Builder for constructing an instance of this type

Implementations

Source

impl<'a> SegmentBuilder<'a, Empty>

pub fn new() -> Self

Create a new builder with all fields unset

Source

impl<'a, S: State> SegmentBuilder<'a, S>

pub fn audio(self, value: impl Into<Option<Vec<Audio<'a>>>>) -> Self

Set the audio field (optional)

pub fn maybe_audio(self, value: Option<Vec<Audio<'a>>>) -> Self

Set the audio field to an Option value (optional)

Source

impl<'a, S: State> SegmentBuilder<'a, S>

pub fn content_rights(self, value: impl Into<Option<ContentRights<'a>>>) -> Self

Set the contentRights field (optional)

pub fn maybe_content_rights(self, value: Option<ContentRights<'a>>) -> Self

Set the contentRights field to an Option value (optional)

Source

impl<'a, S: State> SegmentBuilder<'a, S>

pub fn content_warnings( self, value: impl Into<Option<ContentWarnings<'a>>>, ) -> Self

Set the contentWarnings field (optional)

pub fn maybe_content_warnings(self, value: Option<ContentWarnings<'a>>) -> Self

Set the contentWarnings field to an Option value (optional)

Source

impl<'a, S> SegmentBuilder<'a, S>
where S: State, S::Creator: IsUnset,

pub fn creator( self, value: impl Into<Did<'a>>, ) -> SegmentBuilder<'a, SetCreator<S>>

Set the creator field (required)

Source

impl<'a, S: State> SegmentBuilder<'a, S>

pub fn distribution_policy( self, value: impl Into<Option<DistributionPolicy<'a>>>, ) -> Self

Set the distributionPolicy field (optional)

pub fn maybe_distribution_policy( self, value: Option<DistributionPolicy<'a>>, ) -> Self

Set the distributionPolicy field to an Option value (optional)

Source

impl<'a, S: State> SegmentBuilder<'a, S>

pub fn duration(self, value: impl Into<Option<i64>>) -> Self

Set the duration field (optional)

pub fn maybe_duration(self, value: Option<i64>) -> Self

Set the duration field to an Option value (optional)

Source

impl<'a, S> SegmentBuilder<'a, S>
where S: State, S::Id: IsUnset,

pub fn id(self, value: impl Into<CowStr<'a>>) -> SegmentBuilder<'a, SetId<S>>

Set the id field (required)

Source

impl<'a, S> SegmentBuilder<'a, S>
where S: State, S::SigningKey: IsUnset,

pub fn signing_key( self, value: impl Into<CowStr<'a>>, ) -> SegmentBuilder<'a, SetSigningKey<S>>

Set the signingKey field (required)

Source

impl<'a, S: State> SegmentBuilder<'a, S>

pub fn size(self, value: impl Into<Option<i64>>) -> Self

Set the size field (optional)

pub fn maybe_size(self, value: Option<i64>) -> Self

Set the size field to an Option value (optional)

Source

impl<'a, S> SegmentBuilder<'a, S>
where S: State, S::StartTime: IsUnset,

pub fn start_time( self, value: impl Into<Datetime>, ) -> SegmentBuilder<'a, SetStartTime<S>>

Set the startTime field (required)

Source

impl<'a, S: State> SegmentBuilder<'a, S>

pub fn video(self, value: impl Into<Option<Vec<Video<'a>>>>) -> Self

Set the video field (optional)

pub fn maybe_video(self, value: Option<Vec<Video<'a>>>) -> Self

Set the video field to an Option value (optional)

Source

impl<'a, S> SegmentBuilder<'a, S>
where S: State, S::Id: IsSet, S::StartTime: IsSet, S::SigningKey: IsSet, S::Creator: IsSet,

pub fn build(self) -> Segment<'a>

Build the final struct

pub fn build_with_data( self, extra_data: BTreeMap<SmolStr, Data<'a>>, ) -> Segment<'a>

Build the final struct with custom extra_data