pub struct DocumentBuilder<'a, S: State> { /* private fields */ }Expand description
Builder for constructing an instance of this type
Implementations
Sourceimpl<'a> DocumentBuilder<'a, Empty>
impl<'a> DocumentBuilder<'a, Empty>
Sourceimpl<'a, S> DocumentBuilder<'a, S>
impl<'a, S> DocumentBuilder<'a, S>
Set the author field (required)
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourcepub fn cover_image(self, value: impl Into<Option<BlobRef<'a>>>) -> Self
pub fn cover_image(self, value: impl Into<Option<BlobRef<'a>>>) -> Self
Set the coverImage field (optional)
Sourcepub fn maybe_cover_image(self, value: Option<BlobRef<'a>>) -> Self
pub fn maybe_cover_image(self, value: Option<BlobRef<'a>>) -> Self
Set the coverImage field to an Option value (optional)
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourcepub fn description(self, value: impl Into<Option<CowStr<'a>>>) -> Self
pub fn description(self, value: impl Into<Option<CowStr<'a>>>) -> Self
Set the description field (optional)
Sourcepub fn maybe_description(self, value: Option<CowStr<'a>>) -> Self
pub fn maybe_description(self, value: Option<CowStr<'a>>) -> Self
Set the description field to an Option value (optional)
Sourceimpl<'a, S> DocumentBuilder<'a, S>
impl<'a, S> DocumentBuilder<'a, S>
Sourcepub fn pages(
self,
value: impl Into<Vec<DocumentPagesItem<'a>>>,
) -> DocumentBuilder<'a, SetPages<S>>
pub fn pages( self, value: impl Into<Vec<DocumentPagesItem<'a>>>, ) -> DocumentBuilder<'a, SetPages<S>>
Set the pages field (required)
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourcepub fn preferences(self, value: impl Into<Option<Preferences<'a>>>) -> Self
pub fn preferences(self, value: impl Into<Option<Preferences<'a>>>) -> Self
Set the preferences field (optional)
Sourcepub fn maybe_preferences(self, value: Option<Preferences<'a>>) -> Self
pub fn maybe_preferences(self, value: Option<Preferences<'a>>) -> Self
Set the preferences field to an Option value (optional)
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourcepub fn publication(self, value: impl Into<Option<AtUri<'a>>>) -> Self
pub fn publication(self, value: impl Into<Option<AtUri<'a>>>) -> Self
Set the publication field (optional)
Sourcepub fn maybe_publication(self, value: Option<AtUri<'a>>) -> Self
pub fn maybe_publication(self, value: Option<AtUri<'a>>) -> Self
Set the publication field to an Option value (optional)
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourcepub fn published_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn published_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the publishedAt field (optional)
Sourcepub fn maybe_published_at(self, value: Option<Datetime>) -> Self
pub fn maybe_published_at(self, value: Option<Datetime>) -> Self
Set the publishedAt field to an Option value (optional)
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Set the tags field (optional)
Set the tags field to an Option value (optional)
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourceimpl<'a, S> DocumentBuilder<'a, S>
impl<'a, S> DocumentBuilder<'a, S>
Sourceimpl<'a, S> DocumentBuilder<'a, S>
impl<'a, S> DocumentBuilder<'a, S>