pub struct ProfileViewBuilder<'a, S: State> { /* private fields */ }Expand description
Builder for constructing an instance of this type
Implementations
Sourceimpl<'a> ProfileViewBuilder<'a, Empty>
impl<'a> ProfileViewBuilder<'a, Empty>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Set the banner field (optional)
Set the banner field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn created_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn created_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the createdAt field (optional)
Sourcepub fn maybe_created_at(self, value: Option<Datetime>) -> Self
pub fn maybe_created_at(self, value: Option<Datetime>) -> Self
Set the createdAt field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn description(self, value: impl Into<Option<CowStr<'a>>>) -> Self
pub fn description(self, value: impl Into<Option<CowStr<'a>>>) -> Self
Set the description field (optional)
Sourcepub fn maybe_description(self, value: Option<CowStr<'a>>) -> Self
pub fn maybe_description(self, value: Option<CowStr<'a>>) -> Self
Set the description field to an Option value (optional)
Sourceimpl<'a, S> ProfileViewBuilder<'a, S>
impl<'a, S> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn display_name(self, value: impl Into<Option<CowStr<'a>>>) -> Self
pub fn display_name(self, value: impl Into<Option<CowStr<'a>>>) -> Self
Set the displayName field (optional)
Sourcepub fn maybe_display_name(self, value: Option<CowStr<'a>>) -> Self
pub fn maybe_display_name(self, value: Option<CowStr<'a>>) -> Self
Set the displayName field to an Option value (optional)
Sourceimpl<'a, S> ProfileViewBuilder<'a, S>
impl<'a, S> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn indexed_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn indexed_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the indexedAt field (optional)
Sourcepub fn maybe_indexed_at(self, value: Option<Datetime>) -> Self
pub fn maybe_indexed_at(self, value: Option<Datetime>) -> Self
Set the indexedAt field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn pinned(self, value: impl Into<Option<PinnedList<'a>>>) -> Self
pub fn pinned(self, value: impl Into<Option<PinnedList<'a>>>) -> Self
Set the pinned field (optional)
Sourcepub fn maybe_pinned(self, value: Option<PinnedList<'a>>) -> Self
pub fn maybe_pinned(self, value: Option<PinnedList<'a>>) -> Self
Set the pinned field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn pronouns(self, value: impl Into<Option<PronounsList<'a>>>) -> Self
pub fn pronouns(self, value: impl Into<Option<PronounsList<'a>>>) -> Self
Set the pronouns field (optional)
Sourcepub fn maybe_pronouns(self, value: Option<PronounsList<'a>>) -> Self
pub fn maybe_pronouns(self, value: Option<PronounsList<'a>>) -> Self
Set the pronouns field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn streamplace(self, value: impl Into<Option<bool>>) -> Self
pub fn streamplace(self, value: impl Into<Option<bool>>) -> Self
Set the streamplace field (optional)
Sourcepub fn maybe_streamplace(self, value: Option<bool>) -> Self
pub fn maybe_streamplace(self, value: Option<bool>) -> Self
Set the streamplace field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn subscribed_count(self, value: impl Into<Option<i64>>) -> Self
pub fn subscribed_count(self, value: impl Into<Option<i64>>) -> Self
Set the subscribedCount field (optional)
Sourcepub fn maybe_subscribed_count(self, value: Option<i64>) -> Self
pub fn maybe_subscribed_count(self, value: Option<i64>) -> Self
Set the subscribedCount field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourcepub fn subscriber_count(self, value: impl Into<Option<i64>>) -> Self
pub fn subscriber_count(self, value: impl Into<Option<i64>>) -> Self
Set the subscriberCount field (optional)
Sourcepub fn maybe_subscriber_count(self, value: Option<i64>) -> Self
pub fn maybe_subscriber_count(self, value: Option<i64>) -> Self
Set the subscriberCount field to an Option value (optional)
Sourceimpl<'a, S: State> ProfileViewBuilder<'a, S>
impl<'a, S: State> ProfileViewBuilder<'a, S>
Sourceimpl<'a, S> ProfileViewBuilder<'a, S>
impl<'a, S> ProfileViewBuilder<'a, S>
Sourcepub fn build(self) -> ProfileView<'a>
pub fn build(self) -> ProfileView<'a>
Build the final struct
Sourcepub fn build_with_data(
self,
extra_data: BTreeMap<SmolStr, Data<'a>>,
) -> ProfileView<'a>
pub fn build_with_data( self, extra_data: BTreeMap<SmolStr, Data<'a>>, ) -> ProfileView<'a>
Build the final struct with custom extra_data