pub struct EntryBuilder<'a, S: State> { /* private fields */ }Expand description
Builder for constructing an instance of this type
Implementations
Sourceimpl<'a> EntryBuilder<'a, Empty>
impl<'a> EntryBuilder<'a, Empty>
Sourceimpl<'a, S: State> EntryBuilder<'a, S>
impl<'a, S: State> EntryBuilder<'a, S>
Set the authors field (optional)
Set the authors field to an Option value (optional)
Sourceimpl<'a, S> EntryBuilder<'a, S>
impl<'a, S> EntryBuilder<'a, S>
Sourcepub fn content(
self,
value: impl Into<CowStr<'a>>,
) -> EntryBuilder<'a, SetContent<S>>
pub fn content( self, value: impl Into<CowStr<'a>>, ) -> EntryBuilder<'a, SetContent<S>>
Set the content field (required)
Sourceimpl<'a, S: State> EntryBuilder<'a, S>
impl<'a, S: State> EntryBuilder<'a, S>
Sourcepub fn content_warnings(
self,
value: impl Into<Option<ContentWarnings<'a>>>,
) -> Self
pub fn content_warnings( self, value: impl Into<Option<ContentWarnings<'a>>>, ) -> Self
Set the contentWarnings field (optional)
Sourcepub fn maybe_content_warnings(self, value: Option<ContentWarnings<'a>>) -> Self
pub fn maybe_content_warnings(self, value: Option<ContentWarnings<'a>>) -> Self
Set the contentWarnings field to an Option value (optional)
Sourceimpl<'a, S> EntryBuilder<'a, S>
impl<'a, S> EntryBuilder<'a, S>
Sourcepub fn created_at(
self,
value: impl Into<Datetime>,
) -> EntryBuilder<'a, SetCreatedAt<S>>
pub fn created_at( self, value: impl Into<Datetime>, ) -> EntryBuilder<'a, SetCreatedAt<S>>
Set the createdAt field (required)
Sourceimpl<'a, S: State> EntryBuilder<'a, S>
impl<'a, S: State> EntryBuilder<'a, S>
Sourcepub fn embeds(self, value: impl Into<Option<EntryEmbeds<'a>>>) -> Self
pub fn embeds(self, value: impl Into<Option<EntryEmbeds<'a>>>) -> Self
Set the embeds field (optional)
Sourcepub fn maybe_embeds(self, value: Option<EntryEmbeds<'a>>) -> Self
pub fn maybe_embeds(self, value: Option<EntryEmbeds<'a>>) -> Self
Set the embeds field to an Option value (optional)
Sourceimpl<'a, S> EntryBuilder<'a, S>
impl<'a, S> EntryBuilder<'a, S>
Sourceimpl<'a, S: State> EntryBuilder<'a, S>
impl<'a, S: State> EntryBuilder<'a, S>
Sourcepub fn rating(self, value: impl Into<Option<ContentRating<'a>>>) -> Self
pub fn rating(self, value: impl Into<Option<ContentRating<'a>>>) -> Self
Set the rating field (optional)
Sourcepub fn maybe_rating(self, value: Option<ContentRating<'a>>) -> Self
pub fn maybe_rating(self, value: Option<ContentRating<'a>>) -> Self
Set the rating field to an Option value (optional)
Sourceimpl<'a, S: State> EntryBuilder<'a, S>
impl<'a, S: State> EntryBuilder<'a, S>
Set the tags field (optional)
Set the tags field to an Option value (optional)
Sourceimpl<'a, S> EntryBuilder<'a, S>
impl<'a, S> EntryBuilder<'a, S>
Sourceimpl<'a, S: State> EntryBuilder<'a, S>
impl<'a, S: State> EntryBuilder<'a, S>
Sourcepub fn updated_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn updated_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the updatedAt field (optional)
Sourcepub fn maybe_updated_at(self, value: Option<Datetime>) -> Self
pub fn maybe_updated_at(self, value: Option<Datetime>) -> Self
Set the updatedAt field to an Option value (optional)
Sourceimpl<'a, S> EntryBuilder<'a, S>
impl<'a, S> EntryBuilder<'a, S>