pub struct EntryViewBuilder<'a, S: State> { /* private fields */ }Expand description
Builder for constructing an instance of this type
Implementations
Sourceimpl<'a> EntryViewBuilder<'a, Empty>
impl<'a> EntryViewBuilder<'a, Empty>
Sourceimpl<'a, S> EntryViewBuilder<'a, S>
impl<'a, S> EntryViewBuilder<'a, S>
Set the authors field (required)
Sourceimpl<'a, S: State> EntryViewBuilder<'a, S>
impl<'a, S: State> EntryViewBuilder<'a, S>
Sourcepub fn bookmark_count(self, value: impl Into<Option<i64>>) -> Self
pub fn bookmark_count(self, value: impl Into<Option<i64>>) -> Self
Set the bookmarkCount field (optional)
Sourcepub fn maybe_bookmark_count(self, value: Option<i64>) -> Self
pub fn maybe_bookmark_count(self, value: Option<i64>) -> Self
Set the bookmarkCount field to an Option value (optional)
Sourceimpl<'a, S> EntryViewBuilder<'a, S>
impl<'a, S> EntryViewBuilder<'a, S>
Sourceimpl<'a, S> EntryViewBuilder<'a, S>
impl<'a, S> EntryViewBuilder<'a, S>
Sourcepub fn indexed_at(
self,
value: impl Into<Datetime>,
) -> EntryViewBuilder<'a, SetIndexedAt<S>>
pub fn indexed_at( self, value: impl Into<Datetime>, ) -> EntryViewBuilder<'a, SetIndexedAt<S>>
Set the indexedAt field (required)
Sourceimpl<'a, S: State> EntryViewBuilder<'a, S>
impl<'a, S: State> EntryViewBuilder<'a, S>
Sourcepub fn like_count(self, value: impl Into<Option<i64>>) -> Self
pub fn like_count(self, value: impl Into<Option<i64>>) -> Self
Set the likeCount field (optional)
Sourcepub fn maybe_like_count(self, value: Option<i64>) -> Self
pub fn maybe_like_count(self, value: Option<i64>) -> Self
Set the likeCount field to an Option value (optional)
Sourceimpl<'a, S: State> EntryViewBuilder<'a, S>
impl<'a, S: State> EntryViewBuilder<'a, S>
Sourceimpl<'a, S: State> EntryViewBuilder<'a, S>
impl<'a, S: State> EntryViewBuilder<'a, S>
Sourcepub fn permissions(self, value: impl Into<Option<PermissionsState<'a>>>) -> Self
pub fn permissions(self, value: impl Into<Option<PermissionsState<'a>>>) -> Self
Set the permissions field (optional)
Sourcepub fn maybe_permissions(self, value: Option<PermissionsState<'a>>) -> Self
pub fn maybe_permissions(self, value: Option<PermissionsState<'a>>) -> Self
Set the permissions field to an Option value (optional)
Sourceimpl<'a, S> EntryViewBuilder<'a, S>
impl<'a, S> EntryViewBuilder<'a, S>
Sourceimpl<'a, S: State> EntryViewBuilder<'a, S>
impl<'a, S: State> EntryViewBuilder<'a, S>
Sourcepub fn rendered_view(self, value: impl Into<Option<RenderedView<'a>>>) -> Self
pub fn rendered_view(self, value: impl Into<Option<RenderedView<'a>>>) -> Self
Set the renderedView field (optional)
Sourcepub fn maybe_rendered_view(self, value: Option<RenderedView<'a>>) -> Self
pub fn maybe_rendered_view(self, value: Option<RenderedView<'a>>) -> Self
Set the renderedView field to an Option value (optional)
Sourceimpl<'a, S: State> EntryViewBuilder<'a, S>
impl<'a, S: State> EntryViewBuilder<'a, S>
Set the tags field (optional)
Set the tags field to an Option value (optional)
Sourceimpl<'a, S: State> EntryViewBuilder<'a, S>
impl<'a, S: State> EntryViewBuilder<'a, S>
Sourceimpl<'a, S> EntryViewBuilder<'a, S>
impl<'a, S> EntryViewBuilder<'a, S>
Sourceimpl<'a, S: State> EntryViewBuilder<'a, S>
impl<'a, S: State> EntryViewBuilder<'a, S>
Sourcepub fn viewer_bookmark(self, value: impl Into<Option<AtUri<'a>>>) -> Self
pub fn viewer_bookmark(self, value: impl Into<Option<AtUri<'a>>>) -> Self
Set the viewerBookmark field (optional)
Sourcepub fn maybe_viewer_bookmark(self, value: Option<AtUri<'a>>) -> Self
pub fn maybe_viewer_bookmark(self, value: Option<AtUri<'a>>) -> Self
Set the viewerBookmark field to an Option value (optional)
Sourceimpl<'a, S: State> EntryViewBuilder<'a, S>
impl<'a, S: State> EntryViewBuilder<'a, S>
Sourcepub fn viewer_like(self, value: impl Into<Option<AtUri<'a>>>) -> Self
pub fn viewer_like(self, value: impl Into<Option<AtUri<'a>>>) -> Self
Set the viewerLike field (optional)
Sourcepub fn maybe_viewer_like(self, value: Option<AtUri<'a>>) -> Self
pub fn maybe_viewer_like(self, value: Option<AtUri<'a>>) -> Self
Set the viewerLike field to an Option value (optional)
Sourceimpl<'a, S: State> EntryViewBuilder<'a, S>
impl<'a, S: State> EntryViewBuilder<'a, S>
Sourcepub fn viewer_reading_progress(
self,
value: impl Into<Option<ReadingProgress<'a>>>,
) -> Self
pub fn viewer_reading_progress( self, value: impl Into<Option<ReadingProgress<'a>>>, ) -> Self
Set the viewerReadingProgress field (optional)
Sourcepub fn maybe_viewer_reading_progress(
self,
value: Option<ReadingProgress<'a>>,
) -> Self
pub fn maybe_viewer_reading_progress( self, value: Option<ReadingProgress<'a>>, ) -> Self
Set the viewerReadingProgress field to an Option value (optional)