pub struct Theme<'a> {
pub dark_code_theme: ThemeDarkCodeTheme<'a>,
pub dark_scheme: StrongRef<'a>,
pub default_theme: Option<CowStr<'a>>,
pub fonts: ThemeFonts<'a>,
pub light_code_theme: ThemeLightCodeTheme<'a>,
pub light_scheme: StrongRef<'a>,
pub spacing: ThemeSpacing<'a>,
pub extra_data: Option<BTreeMap<SmolStr, Data<'a>>>,
}Expand description
Theme for a notebook
Fields
dark_code_theme: ThemeDarkCodeTheme<'a>Syntax highlighting theme for dark mode
dark_scheme: StrongRef<'a>Reference to a dark colour scheme
default_theme: Option<CowStr<'a>>Defaults to "auto".
fonts: ThemeFonts<'a>Fonts to be used in the notebook. Can specify a name or list of names (will load if available) or a file or list of files for each. Empty lists will use site defaults.
light_code_theme: ThemeLightCodeTheme<'a>Syntax highlighting theme for light mode
light_scheme: StrongRef<'a>Reference to a light colour scheme
spacing: ThemeSpacing<'a>extra_data: Option<BTreeMap<SmolStr, Data<'a>>>Implementations