pub struct Document<'a> {Show 14 fields
pub bsky_post_ref: Option<StrongRef<'a>>,
pub content: Option<Content<'a>>,
pub cover_image: Option<BlobRef<'a>>,
pub description: Option<CowStr<'a>>,
pub path: Option<CowStr<'a>>,
pub preferences: Option<Preferences<'a>>,
pub published_at: Datetime,
pub site: UriValue<'a>,
pub tags: Option<Vec<CowStr<'a>>>,
pub text_content: Option<CowStr<'a>>,
pub theme: Option<Theme<'a>>,
pub title: CowStr<'a>,
pub updated_at: Option<Datetime>,
pub extra_data: Option<BTreeMap<SmolStr, Data<'a>>>,
}Fields
bsky_post_ref: Option<StrongRef<'a>>content: Option<Content<'a>>cover_image: Option<BlobRef<'a>>description: Option<CowStr<'a>>path: Option<CowStr<'a>>combine with the publication url or the document site to construct a full url to the document
preferences: Option<Preferences<'a>>published_at: Datetimesite: UriValue<'a>URI to the site or publication this document belongs to. Supports both AT-URIs (at://did/collection/rkey) for publication references and HTTPS URLs (https://example.com) for standalone documents or external sites.
text_content: Option<CowStr<'a>>theme: Option<Theme<'a>>Theme for standalone documents. For documents in publications, theme is inherited from the publication.
title: CowStr<'a>updated_at: Option<Datetime>extra_data: Option<BTreeMap<SmolStr, Data<'a>>>Implementations