pub struct DocumentBuilder<'a, S: State> { /* private fields */ }Expand description
Builder for constructing an instance of this type
Implementations
Sourceimpl<'a> DocumentBuilder<'a, Empty>
impl<'a> DocumentBuilder<'a, Empty>
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourcepub fn bsky_post_ref(self, value: impl Into<Option<StrongRef<'a>>>) -> Self
pub fn bsky_post_ref(self, value: impl Into<Option<StrongRef<'a>>>) -> Self
Set the bskyPostRef field (optional)
Sourcepub fn maybe_bsky_post_ref(self, value: Option<StrongRef<'a>>) -> Self
pub fn maybe_bsky_post_ref(self, value: Option<StrongRef<'a>>) -> Self
Set the bskyPostRef field to an Option value (optional)
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourcepub fn cover_image(self, value: impl Into<Option<BlobRef<'a>>>) -> Self
pub fn cover_image(self, value: impl Into<Option<BlobRef<'a>>>) -> Self
Set the coverImage field (optional)
Sourcepub fn maybe_cover_image(self, value: Option<BlobRef<'a>>) -> Self
pub fn maybe_cover_image(self, value: Option<BlobRef<'a>>) -> Self
Set the coverImage field to an Option value (optional)
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourcepub fn description(self, value: impl Into<Option<CowStr<'a>>>) -> Self
pub fn description(self, value: impl Into<Option<CowStr<'a>>>) -> Self
Set the description field (optional)
Sourcepub fn maybe_description(self, value: Option<CowStr<'a>>) -> Self
pub fn maybe_description(self, value: Option<CowStr<'a>>) -> Self
Set the description field to an Option value (optional)
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourcepub fn preferences(self, value: impl Into<Option<Preferences<'a>>>) -> Self
pub fn preferences(self, value: impl Into<Option<Preferences<'a>>>) -> Self
Set the preferences field (optional)
Sourcepub fn maybe_preferences(self, value: Option<Preferences<'a>>) -> Self
pub fn maybe_preferences(self, value: Option<Preferences<'a>>) -> Self
Set the preferences field to an Option value (optional)
Sourceimpl<'a, S> DocumentBuilder<'a, S>
impl<'a, S> DocumentBuilder<'a, S>
Sourcepub fn published_at(
self,
value: impl Into<Datetime>,
) -> DocumentBuilder<'a, SetPublishedAt<S>>
pub fn published_at( self, value: impl Into<Datetime>, ) -> DocumentBuilder<'a, SetPublishedAt<S>>
Set the publishedAt field (required)
Sourceimpl<'a, S> DocumentBuilder<'a, S>
impl<'a, S> DocumentBuilder<'a, S>
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Set the tags field (optional)
Set the tags field to an Option value (optional)
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourcepub fn text_content(self, value: impl Into<Option<CowStr<'a>>>) -> Self
pub fn text_content(self, value: impl Into<Option<CowStr<'a>>>) -> Self
Set the textContent field (optional)
Sourcepub fn maybe_text_content(self, value: Option<CowStr<'a>>) -> Self
pub fn maybe_text_content(self, value: Option<CowStr<'a>>) -> Self
Set the textContent field to an Option value (optional)
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourceimpl<'a, S> DocumentBuilder<'a, S>
impl<'a, S> DocumentBuilder<'a, S>
Sourceimpl<'a, S: State> DocumentBuilder<'a, S>
impl<'a, S: State> DocumentBuilder<'a, S>
Sourcepub fn updated_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn updated_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the updatedAt field (optional)
Sourcepub fn maybe_updated_at(self, value: Option<Datetime>) -> Self
pub fn maybe_updated_at(self, value: Option<Datetime>) -> Self
Set the updatedAt field to an Option value (optional)
Sourceimpl<'a, S> DocumentBuilder<'a, S>
impl<'a, S> DocumentBuilder<'a, S>