pub trait State: Sealed {
type AccentForeground;
type Background;
type Foreground;
type Accent;
}Expand description
State trait tracking which required fields have been set
pub trait State: Sealed {
type AccentForeground;
type Background;
type Foreground;
type Accent;
}State trait tracking which required fields have been set