SubjectStatusViewBuilder

Struct SubjectStatusViewBuilder 

pub struct SubjectStatusViewBuilder<'a, S: State> { /* private fields */ }
Builder for constructing an instance of this type

Implementations

Source

impl<'a> SubjectStatusViewBuilder<'a, Empty>

pub fn new() -> Self

Create a new builder with all fields unset

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn account_stats(self, value: impl Into<Option<AccountStats<'a>>>) -> Self

Set the accountStats field (optional)

pub fn maybe_account_stats(self, value: Option<AccountStats<'a>>) -> Self

Set the accountStats field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn account_strike(self, value: impl Into<Option<AccountStrike<'a>>>) -> Self

Set the accountStrike field (optional)

pub fn maybe_account_strike(self, value: Option<AccountStrike<'a>>) -> Self

Set the accountStrike field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn age_assurance_state( self, value: impl Into<Option<SubjectStatusViewAgeAssuranceState<'a>>>, ) -> Self

Set the ageAssuranceState field (optional)

pub fn maybe_age_assurance_state( self, value: Option<SubjectStatusViewAgeAssuranceState<'a>>, ) -> Self

Set the ageAssuranceState field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn age_assurance_updated_by( self, value: impl Into<Option<SubjectStatusViewAgeAssuranceUpdatedBy<'a>>>, ) -> Self

Set the ageAssuranceUpdatedBy field (optional)

pub fn maybe_age_assurance_updated_by( self, value: Option<SubjectStatusViewAgeAssuranceUpdatedBy<'a>>, ) -> Self

Set the ageAssuranceUpdatedBy field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn appealed(self, value: impl Into<Option<bool>>) -> Self

Set the appealed field (optional)

pub fn maybe_appealed(self, value: Option<bool>) -> Self

Set the appealed field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn comment(self, value: impl Into<Option<CowStr<'a>>>) -> Self

Set the comment field (optional)

pub fn maybe_comment(self, value: Option<CowStr<'a>>) -> Self

Set the comment field to an Option value (optional)

Source

impl<'a, S> SubjectStatusViewBuilder<'a, S>
where S: State, S::CreatedAt: IsUnset,

pub fn created_at( self, value: impl Into<Datetime>, ) -> SubjectStatusViewBuilder<'a, SetCreatedAt<S>>

Set the createdAt field (required)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn hosting( self, value: impl Into<Option<SubjectStatusViewHosting<'a>>>, ) -> Self

Set the hosting field (optional)

pub fn maybe_hosting(self, value: Option<SubjectStatusViewHosting<'a>>) -> Self

Set the hosting field to an Option value (optional)

Source

impl<'a, S> SubjectStatusViewBuilder<'a, S>
where S: State, S::Id: IsUnset,

pub fn id(self, value: impl Into<i64>) -> SubjectStatusViewBuilder<'a, SetId<S>>

Set the id field (required)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn last_appealed_at(self, value: impl Into<Option<Datetime>>) -> Self

Set the lastAppealedAt field (optional)

pub fn maybe_last_appealed_at(self, value: Option<Datetime>) -> Self

Set the lastAppealedAt field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn last_reported_at(self, value: impl Into<Option<Datetime>>) -> Self

Set the lastReportedAt field (optional)

pub fn maybe_last_reported_at(self, value: Option<Datetime>) -> Self

Set the lastReportedAt field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn last_reviewed_at(self, value: impl Into<Option<Datetime>>) -> Self

Set the lastReviewedAt field (optional)

pub fn maybe_last_reviewed_at(self, value: Option<Datetime>) -> Self

Set the lastReviewedAt field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn last_reviewed_by(self, value: impl Into<Option<Did<'a>>>) -> Self

Set the lastReviewedBy field (optional)

pub fn maybe_last_reviewed_by(self, value: Option<Did<'a>>) -> Self

Set the lastReviewedBy field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn mute_reporting_until(self, value: impl Into<Option<Datetime>>) -> Self

Set the muteReportingUntil field (optional)

pub fn maybe_mute_reporting_until(self, value: Option<Datetime>) -> Self

Set the muteReportingUntil field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn mute_until(self, value: impl Into<Option<Datetime>>) -> Self

Set the muteUntil field (optional)

pub fn maybe_mute_until(self, value: Option<Datetime>) -> Self

Set the muteUntil field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn priority_score(self, value: impl Into<Option<i64>>) -> Self

Set the priorityScore field (optional)

pub fn maybe_priority_score(self, value: Option<i64>) -> Self

Set the priorityScore field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn records_stats(self, value: impl Into<Option<RecordsStats<'a>>>) -> Self

Set the recordsStats field (optional)

pub fn maybe_records_stats(self, value: Option<RecordsStats<'a>>) -> Self

Set the recordsStats field to an Option value (optional)

Source

impl<'a, S> SubjectStatusViewBuilder<'a, S>
where S: State, S::ReviewState: IsUnset,

pub fn review_state( self, value: impl Into<SubjectReviewState<'a>>, ) -> SubjectStatusViewBuilder<'a, SetReviewState<S>>

Set the reviewState field (required)

Source

impl<'a, S> SubjectStatusViewBuilder<'a, S>
where S: State, S::Subject: IsUnset,

pub fn subject( self, value: impl Into<SubjectStatusViewSubject<'a>>, ) -> SubjectStatusViewBuilder<'a, SetSubject<S>>

Set the subject field (required)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn subject_blob_cids(self, value: impl Into<Option<Vec<Cid<'a>>>>) -> Self

Set the subjectBlobCids field (optional)

pub fn maybe_subject_blob_cids(self, value: Option<Vec<Cid<'a>>>) -> Self

Set the subjectBlobCids field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn subject_repo_handle(self, value: impl Into<Option<CowStr<'a>>>) -> Self

Set the subjectRepoHandle field (optional)

pub fn maybe_subject_repo_handle(self, value: Option<CowStr<'a>>) -> Self

Set the subjectRepoHandle field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn suspend_until(self, value: impl Into<Option<Datetime>>) -> Self

Set the suspendUntil field (optional)

pub fn maybe_suspend_until(self, value: Option<Datetime>) -> Self

Set the suspendUntil field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn tags(self, value: impl Into<Option<Vec<CowStr<'a>>>>) -> Self

Set the tags field (optional)

pub fn maybe_tags(self, value: Option<Vec<CowStr<'a>>>) -> Self

Set the tags field to an Option value (optional)

Source

impl<'a, S: State> SubjectStatusViewBuilder<'a, S>

pub fn takendown(self, value: impl Into<Option<bool>>) -> Self

Set the takendown field (optional)

pub fn maybe_takendown(self, value: Option<bool>) -> Self

Set the takendown field to an Option value (optional)

Source

impl<'a, S> SubjectStatusViewBuilder<'a, S>
where S: State, S::UpdatedAt: IsUnset,

pub fn updated_at( self, value: impl Into<Datetime>, ) -> SubjectStatusViewBuilder<'a, SetUpdatedAt<S>>

Set the updatedAt field (required)

Source

impl<'a, S> SubjectStatusViewBuilder<'a, S>

pub fn build(self) -> SubjectStatusView<'a>

Build the final struct

pub fn build_with_data( self, extra_data: BTreeMap<SmolStr, Data<'a>>, ) -> SubjectStatusView<'a>

Build the final struct with custom extra_data