pub struct SubjectStatusViewBuilder<'a, S: State> { /* private fields */ }Expand description
Builder for constructing an instance of this type
Implementations
Sourceimpl<'a> SubjectStatusViewBuilder<'a, Empty>
impl<'a> SubjectStatusViewBuilder<'a, Empty>
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn account_stats(self, value: impl Into<Option<AccountStats<'a>>>) -> Self
pub fn account_stats(self, value: impl Into<Option<AccountStats<'a>>>) -> Self
Set the accountStats field (optional)
Sourcepub fn maybe_account_stats(self, value: Option<AccountStats<'a>>) -> Self
pub fn maybe_account_stats(self, value: Option<AccountStats<'a>>) -> Self
Set the accountStats field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn account_strike(self, value: impl Into<Option<AccountStrike<'a>>>) -> Self
pub fn account_strike(self, value: impl Into<Option<AccountStrike<'a>>>) -> Self
Set the accountStrike field (optional)
Sourcepub fn maybe_account_strike(self, value: Option<AccountStrike<'a>>) -> Self
pub fn maybe_account_strike(self, value: Option<AccountStrike<'a>>) -> Self
Set the accountStrike field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn age_assurance_state(
self,
value: impl Into<Option<SubjectStatusViewAgeAssuranceState<'a>>>,
) -> Self
pub fn age_assurance_state( self, value: impl Into<Option<SubjectStatusViewAgeAssuranceState<'a>>>, ) -> Self
Set the ageAssuranceState field (optional)
Sourcepub fn maybe_age_assurance_state(
self,
value: Option<SubjectStatusViewAgeAssuranceState<'a>>,
) -> Self
pub fn maybe_age_assurance_state( self, value: Option<SubjectStatusViewAgeAssuranceState<'a>>, ) -> Self
Set the ageAssuranceState field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn age_assurance_updated_by(
self,
value: impl Into<Option<SubjectStatusViewAgeAssuranceUpdatedBy<'a>>>,
) -> Self
pub fn age_assurance_updated_by( self, value: impl Into<Option<SubjectStatusViewAgeAssuranceUpdatedBy<'a>>>, ) -> Self
Set the ageAssuranceUpdatedBy field (optional)
Sourcepub fn maybe_age_assurance_updated_by(
self,
value: Option<SubjectStatusViewAgeAssuranceUpdatedBy<'a>>,
) -> Self
pub fn maybe_age_assurance_updated_by( self, value: Option<SubjectStatusViewAgeAssuranceUpdatedBy<'a>>, ) -> Self
Set the ageAssuranceUpdatedBy field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourceimpl<'a, S> SubjectStatusViewBuilder<'a, S>
impl<'a, S> SubjectStatusViewBuilder<'a, S>
Sourcepub fn created_at(
self,
value: impl Into<Datetime>,
) -> SubjectStatusViewBuilder<'a, SetCreatedAt<S>>
pub fn created_at( self, value: impl Into<Datetime>, ) -> SubjectStatusViewBuilder<'a, SetCreatedAt<S>>
Set the createdAt field (required)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn hosting(
self,
value: impl Into<Option<SubjectStatusViewHosting<'a>>>,
) -> Self
pub fn hosting( self, value: impl Into<Option<SubjectStatusViewHosting<'a>>>, ) -> Self
Set the hosting field (optional)
Sourcepub fn maybe_hosting(self, value: Option<SubjectStatusViewHosting<'a>>) -> Self
pub fn maybe_hosting(self, value: Option<SubjectStatusViewHosting<'a>>) -> Self
Set the hosting field to an Option value (optional)
Sourceimpl<'a, S> SubjectStatusViewBuilder<'a, S>
impl<'a, S> SubjectStatusViewBuilder<'a, S>
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn last_appealed_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn last_appealed_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the lastAppealedAt field (optional)
Sourcepub fn maybe_last_appealed_at(self, value: Option<Datetime>) -> Self
pub fn maybe_last_appealed_at(self, value: Option<Datetime>) -> Self
Set the lastAppealedAt field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn last_reported_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn last_reported_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the lastReportedAt field (optional)
Sourcepub fn maybe_last_reported_at(self, value: Option<Datetime>) -> Self
pub fn maybe_last_reported_at(self, value: Option<Datetime>) -> Self
Set the lastReportedAt field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn last_reviewed_at(self, value: impl Into<Option<Datetime>>) -> Self
pub fn last_reviewed_at(self, value: impl Into<Option<Datetime>>) -> Self
Set the lastReviewedAt field (optional)
Sourcepub fn maybe_last_reviewed_at(self, value: Option<Datetime>) -> Self
pub fn maybe_last_reviewed_at(self, value: Option<Datetime>) -> Self
Set the lastReviewedAt field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn last_reviewed_by(self, value: impl Into<Option<Did<'a>>>) -> Self
pub fn last_reviewed_by(self, value: impl Into<Option<Did<'a>>>) -> Self
Set the lastReviewedBy field (optional)
Sourcepub fn maybe_last_reviewed_by(self, value: Option<Did<'a>>) -> Self
pub fn maybe_last_reviewed_by(self, value: Option<Did<'a>>) -> Self
Set the lastReviewedBy field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn mute_reporting_until(self, value: impl Into<Option<Datetime>>) -> Self
pub fn mute_reporting_until(self, value: impl Into<Option<Datetime>>) -> Self
Set the muteReportingUntil field (optional)
Sourcepub fn maybe_mute_reporting_until(self, value: Option<Datetime>) -> Self
pub fn maybe_mute_reporting_until(self, value: Option<Datetime>) -> Self
Set the muteReportingUntil field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn mute_until(self, value: impl Into<Option<Datetime>>) -> Self
pub fn mute_until(self, value: impl Into<Option<Datetime>>) -> Self
Set the muteUntil field (optional)
Sourcepub fn maybe_mute_until(self, value: Option<Datetime>) -> Self
pub fn maybe_mute_until(self, value: Option<Datetime>) -> Self
Set the muteUntil field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn priority_score(self, value: impl Into<Option<i64>>) -> Self
pub fn priority_score(self, value: impl Into<Option<i64>>) -> Self
Set the priorityScore field (optional)
Sourcepub fn maybe_priority_score(self, value: Option<i64>) -> Self
pub fn maybe_priority_score(self, value: Option<i64>) -> Self
Set the priorityScore field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn records_stats(self, value: impl Into<Option<RecordsStats<'a>>>) -> Self
pub fn records_stats(self, value: impl Into<Option<RecordsStats<'a>>>) -> Self
Set the recordsStats field (optional)
Sourcepub fn maybe_records_stats(self, value: Option<RecordsStats<'a>>) -> Self
pub fn maybe_records_stats(self, value: Option<RecordsStats<'a>>) -> Self
Set the recordsStats field to an Option value (optional)
Sourceimpl<'a, S> SubjectStatusViewBuilder<'a, S>
impl<'a, S> SubjectStatusViewBuilder<'a, S>
Sourcepub fn review_state(
self,
value: impl Into<SubjectReviewState<'a>>,
) -> SubjectStatusViewBuilder<'a, SetReviewState<S>>
pub fn review_state( self, value: impl Into<SubjectReviewState<'a>>, ) -> SubjectStatusViewBuilder<'a, SetReviewState<S>>
Set the reviewState field (required)
Sourceimpl<'a, S> SubjectStatusViewBuilder<'a, S>
impl<'a, S> SubjectStatusViewBuilder<'a, S>
Sourcepub fn subject(
self,
value: impl Into<SubjectStatusViewSubject<'a>>,
) -> SubjectStatusViewBuilder<'a, SetSubject<S>>
pub fn subject( self, value: impl Into<SubjectStatusViewSubject<'a>>, ) -> SubjectStatusViewBuilder<'a, SetSubject<S>>
Set the subject field (required)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn subject_repo_handle(self, value: impl Into<Option<CowStr<'a>>>) -> Self
pub fn subject_repo_handle(self, value: impl Into<Option<CowStr<'a>>>) -> Self
Set the subjectRepoHandle field (optional)
Sourcepub fn maybe_subject_repo_handle(self, value: Option<CowStr<'a>>) -> Self
pub fn maybe_subject_repo_handle(self, value: Option<CowStr<'a>>) -> Self
Set the subjectRepoHandle field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourcepub fn suspend_until(self, value: impl Into<Option<Datetime>>) -> Self
pub fn suspend_until(self, value: impl Into<Option<Datetime>>) -> Self
Set the suspendUntil field (optional)
Sourcepub fn maybe_suspend_until(self, value: Option<Datetime>) -> Self
pub fn maybe_suspend_until(self, value: Option<Datetime>) -> Self
Set the suspendUntil field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Set the tags field (optional)
Set the tags field to an Option value (optional)
Sourceimpl<'a, S: State> SubjectStatusViewBuilder<'a, S>
impl<'a, S: State> SubjectStatusViewBuilder<'a, S>
Sourceimpl<'a, S> SubjectStatusViewBuilder<'a, S>
impl<'a, S> SubjectStatusViewBuilder<'a, S>
Sourcepub fn updated_at(
self,
value: impl Into<Datetime>,
) -> SubjectStatusViewBuilder<'a, SetUpdatedAt<S>>
pub fn updated_at( self, value: impl Into<Datetime>, ) -> SubjectStatusViewBuilder<'a, SetUpdatedAt<S>>
Set the updatedAt field (required)
Sourceimpl<'a, S> SubjectStatusViewBuilder<'a, S>
impl<'a, S> SubjectStatusViewBuilder<'a, S>
Sourcepub fn build(self) -> SubjectStatusView<'a>
pub fn build(self) -> SubjectStatusView<'a>
Build the final struct
Sourcepub fn build_with_data(
self,
extra_data: BTreeMap<SmolStr, Data<'a>>,
) -> SubjectStatusView<'a>
pub fn build_with_data( self, extra_data: BTreeMap<SmolStr, Data<'a>>, ) -> SubjectStatusView<'a>
Build the final struct with custom extra_data